-- MySQL Workbench Synchronization
-- Generated: 2023-05-19 14:44:57
-- Model: nccs
-- Version: D08.03.10
-- Project: idsteServers
-- Author:

SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

update PlaySessionTime set Length = 0 where Length is null;

ALTER TABLE `nccs`.`PlaySessionTime` MODIFY COLUMN `TempFlag` tinyint NOT NULL DEFAULT 0 AFTER `PlayTime`;

ALTER TABLE `nccs`.`PlaySessionTime` MODIFY COLUMN `Length` int NOT NULL DEFAULT 0 AFTER `TempFlag`;

CREATE TABLE IF NOT EXISTS `nccs`.`EnvDataPm10V2`  (
  `id` int(10) NOT NULL AUTO_INCREMENT,
  `ReportDate` datetime NOT NULL,
  `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '设备ID',
  `Val` float(11, 2) NOT NULL,
  `SpaceID` int(11) NOT NULL DEFAULT 0,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE INDEX `INDEX`(`ReportDate`, `SpaceID`, `DeviceID`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = DYNAMIC;

-- -----------------------------------------------------
-- Table structure for Events
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`Events`  (
    `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '事件id',
    `name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '事件名称',
    `event_type` tinyint(4) UNSIGNED NOT NULL DEFAULT 0 COMMENT '事件类型：0-无效，1-环境检测事件，2-GPIO事件，3-IOT事件，4-中控事件，5-状态检测事件',
    `duration` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '事件持续时间，单位：秒',
    `event_class` tinyint(4) UNSIGNED NOT NULL COMMENT '事件分类，1-设备特有事件，2-公共事件',
    `config` varchar(2048) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '公共事件配置，当even_classt为2时此项有效',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `name`(`name`) USING BTREE COMMENT '名称索引'
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '事件表' ROW_FORMAT = DYNAMIC;

-- -----------------------------------------------------
-- Table structure for DeviceAndEvent
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`DeviceAndEvent`  (
    `dev_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备id',
    `event_id` int(11) UNSIGNED NOT NULL COMMENT '事件id',
    `logic` tinyint(4) UNSIGNED NOT NULL DEFAULT 1 COMMENT '逻辑关系，0-逻辑或，1-逻辑与',
    `triggers` varchar(2048) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '事件触发条件，json字符串',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    UNIQUE INDEX `index`(`dev_id`, `event_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '事件和设备绑定表' ROW_FORMAT = DYNAMIC;

-- ----------------------------
-- Table structure for StrategyInfo
-- ----------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`StrategyInfo`  (
  `ID` int(10) NOT NULL AUTO_INCREMENT,
  `Name` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '策略的名称',
  `StartDateTime` datetime NOT NULL COMMENT '策略开始运行时间。Y-m-d H:m:s格式',
  `EndDateTime` datetime NOT NULL COMMENT '策略运行结束时间。Y-m-d H:m:s格式',
  `Weekday` int(10) NOT NULL COMMENT '表示周几。bit1-bit6表示周一到周六，bit0表示周天',
  `Times` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '每天需要执行按事件执行具体操作的时间范围',
  `Operation` varchar(2048) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '{}' COMMENT '该策略需要执行的操作。json格式',
  `ReceivingEndType` int(10) NOT NULL DEFAULT 1 COMMENT '0: 设备 1：空间，2：分组',
  `Status` tinyint(1) NOT NULL COMMENT '策略运行状态',
  `StartEntryID` int(10) NOT NULL DEFAULT 0,
  `EndEntryID` int(10) NOT NULL DEFAULT 0,
  `UpdateTime` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = DYNAMIC;

-- ----------------------------
-- Table structure for StrategyInfoAndPartitionNode
-- ----------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`StrategyInfoAndPartitionNode`  (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `strategy_id` int(10) NOT NULL COMMENT '环境策略ID',
  `partition_id` int(11) NOT NULL COMMENT '逻辑分区ID',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE INDEX `logical_partition_id`(`partition_id`, `strategy_id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '模式接收成员空间表' ROW_FORMAT = DYNAMIC;

insert into nccs.StrategyInfoAndPartitionNode(strategy_id, partition_id) SELECT env_ctrl_info_id, partition_id from nccs.EnvControlAndPartitionNode;

drop table nccs.EnvControlAndPartitionNode;

-- ----------------------------
-- Table structure for StrategyAndEvent
-- ----------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`StrategyAndEvent`  (
  `id` int(10) NOT NULL AUTO_INCREMENT,
  `strategy_id` int(10) NOT NULL COMMENT '策略id',
  `event_id` int(11) UNSIGNED NOT NULL COMMENT '事件id',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE INDEX `strategy_event`(`strategy_id`, `event_id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8mb4 COLLATE = utf8mb4_general_ci ROW_FORMAT = DYNAMIC;


UPDATE `nccs`.`Users` SET `Mgr_Privilege` = 1, `Dev_Privilege` = 1 WHERE `IsSuper` = 1;


SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;