-- MySQL Workbench Synchronization
-- Generated: 2024-03-27 16:22:56
-- Model: nccs
-- Version: D08.07.03
-- Project: iDsteServers
-- Author:

SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';


ALTER TABLE `nccs`.`Theme`
    MODIFY COLUMN `id` bigint(20) UNSIGNED NOT NULL COMMENT '云端id',
    ADD COLUMN `version` varchar(32) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '主题包版本，如：v1.1.1' AFTER `md5`,
    ADD COLUMN `min_server_ver` varchar(32) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '主题支持的最小服务器版本，取前两个大版本，如：08.06' AFTER `version`,
    ADD COLUMN `preview_group_id` int(11) UNSIGNED NULL DEFAULT NULL COMMENT '扩展应用预览默认分区组ID' AFTER `download_progress`,
    ADD COLUMN `type` tinyint(4) UNSIGNED NOT NULL DEFAULT 0 COMMENT '主题类型，0 - 设备主题，1 - 扩展应用，其他值无效' AFTER `preview_group_id`,
    ADD COLUMN `code` varchar(32) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '主题代码。格式：设备类型_编码，如：bc13_1' AFTER `id`,
    ADD COLUMN `base_path` varchar(64) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '主题解压基本路径。格式：设备类型_编码_主题版本，如：bc13_1_111' AFTER `code`;

-- 历史数据 base_path 更新为 id
UPDATE `nccs`.`Theme` SET `base_path` = CAST(`id` AS CHAR);

ALTER TABLE `nccs`.`ReserveSpaceStatus` MODIFY COLUMN `state` tinyint(4) NOT NULL COMMENT '状态 0：关闭，1：有课，2：开放，3：已预约,4：已锁定（已开始预约）,5: 自习室';

DROP TABLE IF EXISTS `nccs`.`ExtAppConfig`;
CREATE TABLE `nccs`.`ExtAppConfig`  (
    `dev_id` varchar(50) NOT NULL COMMENT '设备ID',
    `type` tinyint(1) UNSIGNED NOT NULL DEFAULT 1 COMMENT '配置类型，1 - idste，2 - 第三方',
    `theme_ids` text NULL COMMENT '关联的云端主题ID，关联多个时id之间以逗号分隔',
    `config` text NULL COMMENT '信息发布配置，非第三方时，URL 动态解析生成',
    `receiving_end_type` int(11) UNSIGNED NOT NULL DEFAULT 1 COMMENT '接收节点类型，0: 设备 1：空间，2：分组',
    `modify_by` int(11) NULL DEFAULT NULL COMMENT '修改人ID',
    `modify_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`dev_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '设备扩展应用配置表' ROW_FORMAT = DYNAMIC;


DROP TABLE IF EXISTS `nccs`.`ExtAppPartitionNode`;
CREATE TABLE `nccs`.`ExtAppPartitionNode`  (
    `dev_id` varchar(50) NOT NULL COMMENT '设备ID',
    `partition_id` int(11) UNSIGNED NOT NULL COMMENT '分区节点ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    UNIQUE INDEX `uidx_devid_nodeid`(`dev_id`, `partition_id`) USING BTREE COMMENT '设备ID和分区节点ID索引'
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '设备扩展应用分区节点绑定表' ROW_FORMAT = DYNAMIC;


DROP TABLE IF EXISTS `nccs`.`Answer`;
CREATE TABLE `nccs`.`Answer`
(
    `id`              int                                                    NOT NULL AUTO_INCREMENT COMMENT '主键',
    `evaluation_id`   int                                                    NOT NULL COMMENT '评论id',
    `question_id`     int                                                    NOT NULL COMMENT '问题ID',
    `title`           varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '问题标题',
    `type`            tinyint                                                NOT NULL DEFAULT '0' COMMENT '0：单项。1：多选，2：简答',
    `order_index`     int                                                    NOT NULL DEFAULT '0' COMMENT '排序号',
    `question_option` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT 'Json 字符串 数组',
    `answer_option`   varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT 'Json 字符串 数组',
    `create_time`     datetime                                               NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_time`     datetime                                               NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  AUTO_INCREMENT = 1
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_bin COMMENT ='巡课评论 答案表';


DROP TABLE IF EXISTS `nccs`.`Evaluation`;
CREATE TABLE `nccs`.`Evaluation`
(
    `id`                     int                                                    NOT NULL AUTO_INCREMENT COMMENT '主键',
    `title`                  varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '评论标题',
    `evaluation_template_id` int                                                    NOT NULL COMMENT '评论模板ID',
    `create_user_id`         int                                                    NOT NULL DEFAULT '0',
    `create_time`            datetime                                               NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_time`            datetime                                               NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  AUTO_INCREMENT = 1
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_bin COMMENT ='巡课评论表';

DROP TABLE IF EXISTS `nccs`.`EvaluationTemplate`;
CREATE TABLE `nccs`.`EvaluationTemplate`
(
    `id`             int          NOT NULL AUTO_INCREMENT COMMENT '主键',
    `title`          varchar(255) NOT NULL DEFAULT '' COMMENT '评论模板标题',
    `is_deleted`     tinyint      NOT NULL DEFAULT '0' COMMENT '0：未删除。1：已删除',
    `create_user_id` int          NOT NULL DEFAULT '0',
    `create_time`    datetime     NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_time`    datetime     NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  AUTO_INCREMENT = 1
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_bin COMMENT ='巡课模板表';

DROP TABLE IF EXISTS `nccs`.`Question`;
CREATE TABLE `nccs`.`Question`
(
    `id`                     int                                                    NOT NULL AUTO_INCREMENT COMMENT '主键',
    `evaluation_template_id` int                                                    NOT NULL COMMENT '评论模板id',
    `title`                  varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '问题标题',
    `type`                   tinyint                                                NOT NULL DEFAULT '0' COMMENT '0：单项。1：多选，2：简答',
    `order_index`            int                                                    NOT NULL DEFAULT '0' COMMENT '排序号',
    `option`                 varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT 'Json 字符串数组',
    `is_deleted`             tinyint                                                NOT NULL DEFAULT '0' COMMENT '0:未删除。1：已删除',
    `create_user_id`         int                                                    NOT NULL DEFAULT '0',
    `create_time`            datetime                                               NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_time`            datetime                                               NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  AUTO_INCREMENT = 10
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_bin COMMENT ='巡课问题表';

ALTER TABLE `nccs`.`CourseRecord`
    ADD COLUMN `evaluation_id` int NOT NULL DEFAULT '0' COMMENT '评论ID' AFTER `record_user_name`;

-- 创建一个默认模板
insert into EvaluationTemplate(id, title)
values (1, '默认模板');

insert into Question(id, evaluation_template_id, title, type, order_index, `option`)
values (1, 1, '评语', 2, 0, '[]');

-- 创建评论
insert into Evaluation(id, title, evaluation_template_id, create_user_id)
select id, '默认模板', 1, record_user_id
from CourseRecord;

insert into Answer(evaluation_id, question_id, title, type, order_index, question_option, answer_option)
select id, 1, '评语', 2, 0, '[]', CONCAT('["', content, '"]')
from CourseRecord;

update CourseRecord c inner join Evaluation e on e.id = c.id
set c.evaluation_id=e.id;

-- user 表添加字段表示 是否拒绝弹出运维公众号
ALTER TABLE `nccs`.`Users`
    ADD COLUMN `NotPopUp` tinyint NOT NULL DEFAULT 0 COMMENT '不弹出公众号引导' AFTER `DefaultPassType`;

-- 教室开放表 新增 节次名称字段
ALTER TABLE `nccs`.`ReserveSpaceStatus`
    ADD COLUMN `section_name` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin DEFAULT '' COMMENT '节次名称' AFTER `section_id`;

-- 设置默认校区 并根据课表中的校区 设置空间的校区
INSERT INTO `nccs`.`Zone`(`name`) VALUES('默认校区') ;

UPDATE `nccs`.`Space` as s INNER JOIN `nccs`.`Timetable`  as t on t.SpaceID=s.id SET s.zone_id=t.ZoneID;

UPDATE `nccs`.`Space` as s INNER JOIN `nccs`.`Zone`  as z on z.`name`='默认校区' SET s.zone_id=z.id WHERE s.zone_id=0 ;

SET SQL_MODE = @OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS = @OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS = @OLD_UNIQUE_CHECKS;
