-- MySQL Workbench Synchronization
-- Generated: 2022-05-06 14:33:28
-- Model: nccs
-- Version: D07.03.26
-- Project: idsteServers
-- Author:


SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

-- 星期几处理
ALTER TABLE `nccs`.`Timetable` MODIFY COLUMN `WeekDay` tinyint(4) NOT NULL DEFAULT 0 COMMENT '上课星期' AFTER `TermName`;

-- 字段新增函数
DROP PROCEDURE IF EXISTS TimeTable_key_proc;
DELIMITER $$
CREATE PROCEDURE TimeTable_key_proc()
  BEGIN
    -- 添加开始节次
    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'Timetable' AND TABLE_SCHEMA = 'nccs' AND COLUMN_NAME = 'StartSection') = 0)
    THEN
     ALTER TABLE `nccs`.`Timetable` ADD COLUMN `StartSection` int(11) NOT NULL DEFAULT 0 COMMENT '开始节次' AFTER `WeekDay`;
    END IF;

    -- 添加结束节次
    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'Timetable' AND TABLE_SCHEMA = 'nccs' AND COLUMN_NAME = 'EndSection') = 0)
    THEN
     ALTER TABLE `nccs`.`Timetable` ADD COLUMN `EndSection` int(11) NOT NULL DEFAULT 0 COMMENT '结束节次' AFTER `Start`;
    END IF;

    -- 添加空间ID
    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'Timetable' AND TABLE_SCHEMA = 'nccs' AND COLUMN_NAME = 'SpaceID') = 0)
    THEN
     ALTER TABLE `nccs`.`Timetable` ADD COLUMN `SpaceID` int(11) NOT NULL COMMENT '空间ID' AFTER `End`;
    END IF;

    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'Timetable' AND TABLE_SCHEMA = 'nccs' AND COLUMN_NAME = 'DevId') != 0)
    THEN
     UPDATE `nccs`.`Timetable` SET `SpaceID` = (IFNULL((SELECT space_id from `nccs`.`SpaceAndDevice` where dev_id = `nccs`.`Timetable`.`DevId`), 0));
    END IF;

    -- 删除index
    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.STATISTICS WHERE TABLE_NAME = 'Timetable' AND TABLE_SCHEMA = 'nccs' AND INDEX_NAME = 'table_idx') != 0)
    THEN
     ALTER TABLE `nccs`.`Timetable` DROP INDEX `table_idx`;
    END IF;

    -- 增加空间名称
    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'Timetable' AND TABLE_SCHEMA = 'nccs' AND COLUMN_NAME = 'ClassName') = 0)
    THEN
     ALTER TABLE `nccs`.`Timetable` ADD COLUMN `ClassName` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT "" COMMENT '教室名称' AFTER `SpaceID`;
    END IF;

    -- 增加用户信息
    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'Timetable' AND TABLE_SCHEMA = 'nccs' AND COLUMN_NAME = 'UserSn') = 0)
    THEN
     ALTER TABLE `nccs`.`Timetable` ADD COLUMN `UserSn` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT "" COMMENT '老师工号' AFTER `UserId`;
    END IF;

    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'Timetable' AND TABLE_SCHEMA = 'nccs' AND COLUMN_NAME = 'UserName') = 0)
    THEN
     ALTER TABLE `nccs`.`Timetable` ADD COLUMN `UserName` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT "" COMMENT '老师姓名' AFTER `UserSn`;
    END IF;

    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'Timetable' AND TABLE_SCHEMA = 'nccs' AND COLUMN_NAME = 'CourseName') = 0)
    THEN
     ALTER TABLE `nccs`.`Timetable` ADD COLUMN `CourseName` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT "" COMMENT '课程名称' AFTER `UserName`;
    END IF;

  END $$
DELIMITER ;
CALL TimeTable_key_proc;
DROP PROCEDURE IF EXISTS TimeTable_key_proc;

-- 开始节次赋值
ALTER TABLE `nccs`.`Timetable` MODIFY COLUMN `Start` datetime(0) NOT NULL DEFAULT '9999-12-31 23:59:59' COMMENT '开始时间' AFTER `StartSection`;
UPDATE `nccs`.`Timetable` SET `StartSection` = (IFNULL((SELECT `section` from `nccs`.`SectionTable` where `start` = time(`nccs`.`Timetable`.`Start`) limit 1), 0));

-- 结束节次赋值
ALTER TABLE `nccs`.`Timetable` MODIFY COLUMN `End` datetime(0) NOT NULL DEFAULT '0000-01-01 00:00:00' COMMENT '结束时间' AFTER `EndSection`;
UPDATE `nccs`.`Timetable` SET `EndSection` =  (IFNULL((SELECT `section` from `nccs`.`SectionTable` where `end` = time(`nccs`.`Timetable`.`End`) limit 1), 0));

-- 空间赋值
UPDATE `nccs`.`Timetable` SET `ClassName` = (IFNULL((SELECT `name` from `nccs`.`Space` where id = `nccs`.`Timetable`.`SpaceID`), ''));

-- 用户赋值
ALTER TABLE `nccs`.`Timetable` MODIFY COLUMN `UserId` int(11) NOT NULL DEFAULT 0 COMMENT '老师在idste系统ID' AFTER `ClassName`;
UPDATE `nccs`.`Timetable` SET `UserSn` = (IFNULL((SELECT `User_Sn` from `nccs`.`Users` where `User_ID` = `nccs`.`Timetable`.`UserId`),""));
UPDATE `nccs`.`Timetable` SET `UserName` = (IFNULL((SELECT `User_Desc` from `nccs`.`Users` where `User_ID` = `nccs`.`Timetable`.`UserId`), ''));

-- 索引新增函数
DROP PROCEDURE IF EXISTS TimeTable_key_proc;
DELIMITER $$
CREATE PROCEDURE TimeTable_key_proc()
  BEGIN
    -- only
    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.STATISTICS WHERE TABLE_NAME = 'Timetable' AND TABLE_SCHEMA = 'nccs' AND INDEX_NAME = 'only') = 0)
    THEN
     ALTER TABLE `nccs`.`Timetable` ADD UNIQUE INDEX `only`(`SpaceID`, `UserId`, `WeekDay`, `Start`, `End`, `Type`, `TermName`) USING BTREE;
    END IF;

    -- deviceId_idx
    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.STATISTICS WHERE TABLE_NAME = 'Timetable' AND TABLE_SCHEMA = 'nccs' AND INDEX_NAME = 'deviceId_idx') = 0)
    THEN
     ALTER TABLE `nccs`.`Timetable` ADD INDEX `deviceId_idx`(`SpaceID`) USING BTREE;
    END IF;

    -- table_idx
    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.STATISTICS WHERE TABLE_NAME = 'Timetable' AND TABLE_SCHEMA = 'nccs' AND INDEX_NAME = 'table_idx') = 0)
    THEN
     ALTER TABLE `nccs`.`Timetable` ADD INDEX `table_idx`(`SpaceID`, `UserId`) USING BTREE;
    END IF;

    -- 删除DevId
    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'Timetable' AND TABLE_SCHEMA = 'nccs' AND COLUMN_NAME = 'DevId') != 0)
    THEN
     ALTER TABLE `nccs`.`Timetable` DROP COLUMN `DevId`;
    END IF;

  END $$
DELIMITER ;
CALL TimeTable_key_proc;
DROP PROCEDURE IF EXISTS TimeTable_key_proc;


-- 其他表处理
DROP PROCEDURE IF EXISTS Other_key_proc;
DELIMITER $$
CREATE PROCEDURE Other_key_proc()
  BEGIN

    IF((SELECT COUNT(*) FROM nccs.`PlayerKeys` WHERE `Index` >  10 and left(PlayerID,2)='30') != 0)
    THEN
     DELETE FROM `LogicClasses` WHERE `id` IN (SELECT `logic_class_id` FROM `PlayerKeys` WHERE `Index` >  10 and left(PlayerID,2)='30');
     DELETE FROM  `PlayerKeys` WHERE `Index` >  10 and left(PlayerID,2)='30';
     DELETE a FROM PlayerKeys a INNER JOIN   (SELECT PlayerID FROM nccs.PlayerKeys WHERE `Index`=10 and left(PlayerID,2)='30') as b on b.PlayerID=a.PlayerID WHERE a.`INDEX`=0;
     UPDATE  PlayerKeys a INNER JOIN   (SELECT PlayerID FROM nccs.PlayerKeys WHERE `Index`=10 and left(PlayerID,2)='30') as b on b.PlayerID=a.PlayerID  SET a.`Index`=a.`Index`-1;
    END IF;


    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.`COLUMNS` WHERE TABLE_NAME = 'OAuthAppInfo' AND TABLE_SCHEMA = 'nccs' AND COLUMN_NAME = 'Id') = 0)
    THEN
     ALTER TABLE `nccs`.`OAuthAppInfo` ADD COLUMN `Id` INT AUTO_INCREMENT PRIMARY KEY FIRST;
     ALTER TABLE `nccs`.`OAuthAppInfo` ADD COLUMN `SyncValue` int(11) NOT NULL DEFAULT 1 COMMENT '数据更新自动加1' AFTER `RedirectUrl`;
    END IF;

    IF((SELECT COUNT(*) FROM INFORMATION_SCHEMA.`COLUMNS` WHERE TABLE_NAME = 'Firmware' AND TABLE_SCHEMA = 'nccs' AND COLUMN_NAME = 'school_id') != 0)
    THEN
     DELETE `nccs`.`Firmware`  FROM nccs.Firmware INNER JOIN (SELECT min(a.id) as id,a.name FROM Firmware a GROUP BY a.`name` HAVING Count(a.id)>1)  as b on ( nccs.Firmware.name=b.name and nccs.Firmware.id>b.id) ;
     ALTER TABLE `nccs`.`Firmware` DROP COLUMN `school_id`;
    END IF;

  END $$
DELIMITER ;
CALL Other_key_proc;
DROP PROCEDURE IF EXISTS Other_key_proc;

SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;