﻿-- MySQL Workbench Forward Engineering

SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

-- -----------------------------------------------------
-- Schema mydb
-- -----------------------------------------------------
-- -----------------------------------------------------
-- Schema nccs
-- -----------------------------------------------------

-- -----------------------------------------------------
-- Schema nccs
-- -----------------------------------------------------
CREATE SCHEMA IF NOT EXISTS `nccs` DEFAULT CHARACTER SET utf8 ;
USE `nccs` ;

-- -----------------------------------------------------
-- Table `nccs`.`AlternateDate`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`AlternateDate` ;

CREATE TABLE `nccs`.`AlternateDate`  (
  `SpecialDate` date NOT NULL,
  `AlteredScheduleDay` tinyint(4) NULL DEFAULT NULL,
  PRIMARY KEY (`SpecialDate`)
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;


-- -----------------------------------------------------
-- Table `nccs`.`BaseInfo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`BaseInfo` ;

CREATE TABLE IF NOT EXISTS `nccs`.`BaseInfo` (
  `InfomationID` INT(11) NOT NULL DEFAULT '0' COMMENT '0~0x04 : air condition command description;\n0x80: User name;\n0x100: MediaFile auto_increasement value;\n0x101 Active task template;\n0x200: Version;',
  `Description` VARCHAR(1024) NULL DEFAULT NULL,
  `InfoValue` BIGINT(20) NULL DEFAULT NULL,
  PRIMARY KEY (`InfomationID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`BroadcastMode`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`BroadcastMode` ;

CREATE TABLE IF NOT EXISTS `nccs`.`BroadcastMode` (
  `idBroadcastMode` INT(11) NOT NULL AUTO_INCREMENT,
  `ModeName` VARCHAR(50) NULL DEFAULT NULL,
  `Priority` INT(11) NOT NULL DEFAULT '10',
  `Enabled` TINYINT(1) NULL DEFAULT '0',
  `StartTime` DATETIME NULL DEFAULT NULL,
  `StopTime` DATETIME NULL DEFAULT NULL,
  `TimeStyle` TINYINT(4) NULL DEFAULT '0' COMMENT '0: means for one day\n   the start date and end date is indicated by starttime and stoptime.\n\nother: means the mode should be repeated weekly.\nbit 0: means sunday\nbit1:  monday\nbit2: tuesday\n...',
  `Active` TINYINT(1) NOT NULL DEFAULT '0',
  `StartEntryID` INT(11) NOT NULL DEFAULT '0',
  `StopEntryID` INT(11) NOT NULL DEFAULT '0',
  `ReceivingEndType` int(11) NOT NULL DEFAULT '1' COMMENT '0:设备，1：空间 ，2：分组',
  PRIMARY KEY (`idBroadcastMode`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DevClasses`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DevClasses` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DevClasses` (
  `ClassID` INT(11) NOT NULL AUTO_INCREMENT,
  `Name` VARCHAR(50) NULL DEFAULT NULL,
  `Parent` INT(11) NULL DEFAULT NULL,
  PRIMARY KEY (`ClassID`),
  INDEX `ClassParent` (`Parent` ASC),
  CONSTRAINT `ClassParent`
    FOREIGN KEY (`Parent`)
    REFERENCES `nccs`.`DevClasses` (`ClassID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DeviceList`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceList` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceList` (
  `DevID` VARCHAR(50) NOT NULL,
  `Dev_Name` VARCHAR(32) NULL DEFAULT NULL,
  `Parent` INT(11) NULL DEFAULT NULL,
  `DisableParentSchedule` TINYINT(4) NULL DEFAULT '0' COMMENT 'Indicate whether disable inheritting schedule setting from parents groups.',
  `Dev_Description` VARBINARY(96) NULL DEFAULT NULL,
  `Dev_Configuration` VARBINARY(2048) NULL DEFAULT NULL,
  `RtspUrl` VARCHAR(512) NULL DEFAULT NULL,
  `RtspSub` VARCHAR(512) NULL DEFAULT NULL,
  `RtspUrl1` VARCHAR(512) NULL DEFAULT NULL,
  `RtspSub1` VARCHAR(512) NULL DEFAULT NULL,
  `ProjWatermark` INT(10) UNSIGNED NOT NULL DEFAULT '360000000',
  `ProjUsedTime` INT(10) UNSIGNED NOT NULL DEFAULT '0',
  `Dev_ConfigurationV2` longtext NULL DEFAULT NULL,
  `PcIp` VARCHAR(41) NULL DEFAULT NULL,
  `PcPort` INT(10) UNSIGNED NULL DEFAULT NULL,
  `PcMainPasswd` VARCHAR(32) NULL DEFAULT NULL,
  `PcViewPasswd` VARCHAR(32) NULL DEFAULT NULL,
  `RfInvalid` INT(10) UNSIGNED NULL DEFAULT '0',
  `Ip` VARCHAR(50) NULL DEFAULT NULL,
  `Proto` INT(10) NULL DEFAULT '1',
  `DevType` INT(11) NOT NULL DEFAULT '0',
  `DoubleClass` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否支持双师课堂 0-不支持 1-支持',
  `ProtocolDevName` varchar(16) DEFAULT '' COMMENT '协议设备类型',
  `CreateTime` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`DevID`),
  UNIQUE INDEX `DevID_UNIQUE` (`DevID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `nccs`.`DevStartingPic`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DevStartingPic`;

CREATE TABLE IF NOT EXISTS `nccs`.`DevStartingPic`  (
  `Type` tinyint(4) NOT NULL COMMENT '图片类型，0---TM03背景图，1---TM03前景图，2---面板开机图片',
  `User` int(11) NULL DEFAULT NULL COMMENT '上传用户ID',
  `Path` varchar(255) NOT NULL COMMENT '文件路径',
  `SyncVal` int(11) NOT NULL DEFAULT 1 COMMENT '整数同步字',
  PRIMARY KEY (`Type`) USING BTREE)
ENGINE = InnoDB
CHARACTER SET = utf8;



-- -----------------------------------------------------
-- Table `nccs`.`DevCtrlSchedule`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DevCtrlSchedule` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DevCtrlSchedule` (
  `ScheduleID` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
  `DevID` VARCHAR(50) NOT NULL,
  `ActionTime` TIME NOT NULL,
  `Action` INT(11) NULL DEFAULT NULL,
  `WeekDay` TINYINT(4) NOT NULL,
  `State` INT(11) NULL DEFAULT '0',
  `ExtArgs` VARCHAR(256) NULL DEFAULT NULL,
  `Disable` TINYINT(1) NULL DEFAULT '0',
  PRIMARY KEY (`DevID`, `ActionTime`, `WeekDay`),
  UNIQUE INDEX `ScheduleID_UNIQUE` (`ScheduleID` ASC),
  INDEX `DeviD` (`DevID` ASC),
  INDEX `DeviceID` (`DevID` ASC),
  INDEX `DevCtrlDevId` (`DevID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DeviceAuthSupplyLog`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceAuthSupplyLog` ;

CREATE TABLE `DeviceAuthSupplyLog` (
  `Id` int(11) NOT NULL AUTO_INCREMENT,
  `Type` varchar(255) NOT NULL DEFAULT '' COMMENT '认证类型',
  `Supply` varchar(255) NOT NULL DEFAULT '' COMMENT '供应商',
  `Url` varchar(1024) NOT NULL DEFAULT '' COMMENT '请求URL',
  `ReqInfo` varchar(4096) NOT NULL DEFAULT '' COMMENT '请求数据',
  `ResInfo` varchar(4096) NOT NULL DEFAULT '' COMMENT '响应数据',
  `Result` tinyint(4) NOT NULL DEFAULT '0' COMMENT '请求结果 0-失败 1-成功',
  `ErrorType` tinyint(4) NOT NULL DEFAULT '0' COMMENT '错误类型 0-无错误 1-系统未配置好 2-供应商返回错误 3-人员信息未找到 4-网络出现问题',
  `Error` varchar(4096) NOT NULL DEFAULT '' COMMENT '错误信息',
  `StartTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '开始时间',
  `EndTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '结束时间',
  `UseTime` int(11) NOT NULL DEFAULT '0' COMMENT '耗时（毫秒数）',
  `Sync` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否同步 0-未同步 1-已同步',
  `AddTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '添加时间',
  PRIMARY KEY (`Id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8 COMMENT='设备认证供应商日志';



-- -----------------------------------------------------
-- Table `nccs`.`DeviceExt`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`DeviceExt` (
  `DevID` VARCHAR(50) NOT NULL,
  `Name` VARCHAR(45) NOT NULL,
  `Config` VARCHAR(2048) NOT NULL DEFAULT '{}',
  UNIQUE INDEX `DeviceExt_uni` (`DevID` ASC, `Name` ASC),
  INDEX `DeviceExt_idx` (`DevID` ASC, `Name` ASC),
  CONSTRAINT `DevID`
    FOREIGN KEY (`DevID`)
    REFERENCES `nccs`.`DeviceList` (`DevID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COMMENT = '设备扩展信息表';


-- -----------------------------------------------------
-- Table `nccs`.`DeviceLog`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceLog` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceLog` (
  `DevLogID` BIGINT(20) NOT NULL AUTO_INCREMENT,
  `DeviceID` VARCHAR(50) NULL DEFAULT NULL,
  `DeviceName` VARCHAR(255) NOT NULL DEFAULT '' COMMENT '设备位置名称',
  `DateTime` DATETIME NOT NULL,
  `Event` TINYINT(4) NULL DEFAULT NULL COMMENT '1  offline/online\n2  power on/power off\n3  enabled/  disabled\n4  Normal Text Message',
  `CtrlUser` INT(11) NULL DEFAULT NULL,
  `UserName` VARCHAR(255) NOT NULL DEFAULT '' COMMENT '用户姓名',
  `MsgContext` VARCHAR(256) NULL DEFAULT NULL,
  `EndTime` DATETIME NULL DEFAULT NULL,
  PRIMARY KEY (`DevLogID`,`DateTime`),
  INDEX `endTime_idx` USING BTREE (`EndTime` ASC),
  INDEX `dateTime_idx` USING BTREE (`DateTime` ASC),
  INDEX `device_idx` USING BTREE (`DeviceID` ASC, `Event` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COMMENT = 'Devices log';


-- -----------------------------------------------------
-- Table `nccs`.`DeviceCtrlList`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceCtrlList` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceCtrlList` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
  `DevID` VARCHAR(50) NOT NULL,
  `SubID` INT(11) NOT NULL,
  `State` INT(11) NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `index` USING BTREE (`DevID` ASC, `SubID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DeviceStatistic`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceStatistic` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceStatistic` (
  `DeviceID` VARCHAR(50) NOT NULL,
  `StatisticDay` DATE NOT NULL,
  `PowerConsumed` BINARY(128) NULL DEFAULT NULL,
  `UsedTime` BINARY(128) NULL DEFAULT NULL,
  `DataState` int(1) DEFAULT NULL,
  PRIMARY KEY (`DeviceID`, `StatisticDay`),
  INDEX `StatisticDay` USING BTREE (`StatisticDay` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`Players`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Players` ;

CREATE TABLE IF NOT EXISTS `nccs`.`Players` (
  `PlayerID` VARCHAR(50) NOT NULL,
  `PlayerName` VARBINARY(32) NULL DEFAULT NULL,
  `PlayerType` TINYINT(4) NULL DEFAULT NULL COMMENT '0: celt audio player\n8: vlc player',
  `Priority` TINYINT(4) NULL DEFAULT '10',
  `Remark` VARBINARY(96) NULL DEFAULT NULL,
  `RtmpURL` VARCHAR(255) NOT NULL DEFAULT '',
  `ShareInfo` varchar(1024) NOT NULL DEFAULT '',
  `ProtocolDevName` varchar(16) DEFAULT '' COMMENT '协议设备类型',
  `AudioChannelConfig` VARCHAR(1024) NOT NULL DEFAULT '' COMMENT '音频通道配置',
  `SyncValue` int(11) NULL DEFAULT 0 COMMENT '播放列表同步字',
  PRIMARY KEY (`PlayerID`),
  UNIQUE INDEX `ID_UNIQUE` (`PlayerID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `nccs`.`PlayerScenes` 采播场景
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayerScenes` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayerScenes` (
  `PlayerID` varchar(50) NOT NULL DEFAULT '' COMMENT '采播设备ID',
  `SceneID` int(11) NOT NULL DEFAULT '1' COMMENT '采播设备场景ID',
  `SceneName` varchar(96) NOT NULL DEFAULT '' COMMENT '场景名称（不能超过32个汉字）',
  `SceneCtrlList` varchar(4096) NOT NULL DEFAULT '' COMMENT '场景控制列表，为json字符串',
  PRIMARY KEY (`PlayerID`,`SceneID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='采播场景';

-- -----------------------------------------------------
-- Table `nccs`.`Users`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Users` ;

CREATE TABLE IF NOT EXISTS `nccs`.`Users` (
    `User_ID` int(11) NOT NULL AUTO_INCREMENT,
    `User_Name` varchar(255) DEFAULT NULL collate utf8_bin COMMENT '用户登录名',
    `User_Desc` varchar(255) NOT NULL DEFAULT '' COMMENT '用户姓名',
    `Pass_Word` varchar(255) NOT NULL DEFAULT '' COMMENT 'password, encode with PASSWORD()',
    `UsbKey` varchar(50) DEFAULT NULL COMMENT 'when the user''s authorization is expired.',
    `Priority` int(11) NOT NULL DEFAULT '100' COMMENT '用户优先级 值越小。优先级越高',
    `IsSuper` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否是超级管理员',
    `privilege` int(11) NOT NULL DEFAULT '0' COMMENT 'Bit 0: privilege of device control.\nBit1~Bit7: Reservered\n\nBit 8: privilege of creating audio and vedio broadcast tasks.\nBit9~Bit15: Reservered\n',
    `PrivilegeList` varchar(4096) NOT NULL DEFAULT '' COMMENT '用户权限列表',
    `IcCard` varchar(50) DEFAULT NULL,
    `Phone` varchar(50) DEFAULT NULL,
    `ServerSync` tinyint(4) NOT NULL DEFAULT '1' COMMENT 'Flag for sync data to cloud server, set when data is inserted or updated, clear after the changed data sysnc to cloud server.',
    `User_Type` tinyint(4) NOT NULL DEFAULT '2' COMMENT '用户类型：\n1：学生\n2：教师\n3：临时人员 \n4：学校管理员 \n5：平台管理员',
    `User_Sn` varchar(20) DEFAULT NULL collate utf8_bin COMMENT '学号或工号',
    `ICCardExpiry` datetime DEFAULT NULL COMMENT 'IC卡有效期\nUser_Type=3时需要检查IC卡过期时间\n时间为0表示不过期',
    `UserExpiry`  bigint(20) UNSIGNED NULL DEFAULT NULL COMMENT '用户有效期，unix 秒级时间戳，NULL表示未设置，0 表示永不过期',
    `Mgr_Privilege` tinyint(1) NOT NULL DEFAULT '0' COMMENT '设备管理权限标志\n0：具有部分权限，需要查询UserDevices表\n1：具有全部权限，无需查询UserDevices表',
    `Dev_Privilege` tinyint(1) NOT NULL DEFAULT '0' COMMENT '设备使用权限标志\n0：具有部分权限，需要查询UserDevices表\n1：具有全部权限，无需查询UserDevices表',
    `Create_Type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '用户创建类型\n0：手动创建\n1：自动(IC卡同步)创建\n',
    `IC_Status` tinyint(1) NOT NULL DEFAULT '0' COMMENT 'IC卡状态\n0：IC卡正常\n1：IC卡挂失',
    `Dpm_Sn` varchar(20) NOT NULL DEFAULT '' COMMENT '部门编号',
    `Dpm_Name` varchar(100) NOT NULL DEFAULT '' COMMENT '部门名称',
    `Del_Flag` tinyint(1) NOT NULL DEFAULT '0' COMMENT 'delete flag:\n0: normal\n1: deleted',
    `UnionId` varchar(64) DEFAULT NULL,
    `UpdatePwdTime` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '密码更新时间。初始化时间为当前时间',
    `SyncLockStartTime` datetime DEFAULT NULL COMMENT '用户锁定开始时间 yyyy:MM:dd HH:mm:ss',
    `SyncLockEndTime` datetime DEFAULT NULL COMMENT '用户锁定结束时间 yyyy:MM:dd HH:mm:ss',
    `UseReceivingEndType` int(11) NOT NULL DEFAULT '1',
    `MgrReceivingEndType` int(11) NOT NULL DEFAULT '1',
    `QrCode` varchar(255) NOT NULL DEFAULT '' COMMENT '静态二维码',
    `IsAlarmMsgReceiver` tinyint(1) NOT NULL DEFAULT 0 COMMENT '是否是告警消息接收用户，0-否，1-是',
    `IsFirstLogin` tinyint(1) UNSIGNED NOT NULL DEFAULT 0 COMMENT '是否首次登录，0-否，1-是',
    `DefaultPassType` tinyint(1) UNSIGNED NOT NULL DEFAULT 0 COMMENT '初始默认密码类型，0-非初始密码，1-学工号，2-手机号，3-IC卡号',
    `NotPopUp` tinyint NOT NULL DEFAULT 0 COMMENT '不弹出公众号引导',
  PRIMARY KEY (`User_ID`),
  UNIQUE INDEX `User_Name_UNIQUE` (`User_Name` ASC),
  UNIQUE INDEX `IcCard_UNIQUE` (`IcCard` ASC),
  UNIQUE INDEX `User_Sn_UNIQUE` (`User_Sn` ASC),
  UNIQUE INDEX `Phone_UNIQUE` (`Phone` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- --------------------------------------------
-- Table structure for `nccs`.`DoubleClass`
-- --------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DoubleClass`;
CREATE TABLE `nccs`.`DoubleClass` (
  `ClassId` int(11) NOT NULL AUTO_INCREMENT COMMENT '课堂ID',
  `ClassName` varchar(255) NOT NULL DEFAULT '' COMMENT '课堂名称',
  `ExecTime` enum('WeekLoop','FixedTime') NOT NULL DEFAULT 'FixedTime' COMMENT 'WeekLoop - 按周循环  FixedTime - 固定时间',
  `FixStime` bigint(20) NOT NULL DEFAULT '0' COMMENT '固定时间 - 开始时间',
  `FixEtime` bigint(20) NOT NULL DEFAULT '0' COMMENT '固定时间 - 结束时间',
  `WeekStime` time NOT NULL COMMENT '按周循环 - 开始时间',
  `WeekEtime` time NOT NULL COMMENT '按周循环 - 结束时间',
  `WeekDays` varchar(255) NOT NULL DEFAULT '' COMMENT '0-6 对应 星期一 到 星期天 (英文逗号分隔,结束都加英文逗号)',
  `Valid` tinyint(4) NOT NULL DEFAULT '1' COMMENT '是否有效 1-有效 0-无效',
  `ConfigMd5` varchar(255) NOT NULL DEFAULT '' COMMENT '配置MD5',
  `AddTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '添加时间',
  `ModTIme` bigint(20) NOT NULL DEFAULT '0' COMMENT '修改时间',
  `NextStime` bigint(20) NOT NULL DEFAULT '0' COMMENT '下次开始时间',
  `NextEtime` bigint(20) NOT NULL DEFAULT '0' COMMENT '下次结束时间',
  `CourseId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂课程ID',
  `CourseTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '上课时间',
  `CourseStatus` enum('free','active','stop','fault') NOT NULL DEFAULT 'free' COMMENT '上课状态（无课-free  上课-active  停止-stop  故障-fault）',
  `CourseFault` varchar(1024) NOT NULL DEFAULT '' COMMENT '课程故障原因',
  PRIMARY KEY (`ClassId`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='双师课堂列表';


-- -----------------------------------------------
-- Table structure for `nccs`.`DoubleClassDevice`
-- -----------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DoubleClassDevice`;
CREATE TABLE `nccs`.`DoubleClassDevice` (
  `Id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
  `ClassId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂ID',
  `SpaceID` int(11) NOT NULL DEFAULT '0' COMMENT '教室（空间）ID',
  `DevId` varchar(50) NOT NULL DEFAULT '' COMMENT '设备ID',
  `ClassType` enum('lead','follow') NOT NULL DEFAULT 'lead' COMMENT '教室类型（lead - 主讲教室  follow - 辅讲教室）',
  `DeviceType` enum('main','slave') NOT NULL DEFAULT 'main' COMMENT '设备类型（main - 主控设备  slave - 从设备）',
  `Ip` varchar(255) NOT NULL DEFAULT '' COMMENT '设备IP地址',
  `CmdConfig` tinyint(4) NOT NULL DEFAULT '0' COMMENT '0-未发送配置命令 1-已发送配置命令',
  `CmdConfigTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '发送配置命令时间',
  PRIMARY KEY (`Id`),
  UNIQUE KEY `ClassDev` (`ClassId`,`DevId`),
  KEY `ClassId` (`ClassId`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='双师课堂设备';


-- ----------------------------------------------
-- Table structure for `nccs`.`DoubleClassCourse`
-- ----------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DoubleClassCourse`;
CREATE TABLE `nccs`.`DoubleClassCourse` (
  `CourseId` int(11) NOT NULL AUTO_INCREMENT COMMENT '课程ID',
  `ClassId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂ID',
  `ClassName` varchar(255) NOT NULL DEFAULT '' COMMENT '课堂名称',
  `ExecTime` enum('WeekLoop','FixedTime') NOT NULL DEFAULT 'FixedTime' COMMENT '执行时间',
  `FixStime` bigint(20) NOT NULL DEFAULT '0' COMMENT '固定时间-开始时间',
  `FixEtime` bigint(20) NOT NULL DEFAULT '0' COMMENT '固定时间 - 结束时间',
  `WeekStime` time NOT NULL COMMENT '按周循环-开始时间',
  `WeekEtime` time NOT NULL COMMENT '按周循环-结束时间',
  `WeekDays` varchar(255) NOT NULL DEFAULT '' COMMENT '0-6 对应 星期一 到 星期天 (英文逗号分隔,结束加英文逗号)',
  `CourseStime` bigint(20) NOT NULL DEFAULT '0' COMMENT '课程开始时间',
  `CourseEtime` bigint(20) NOT NULL DEFAULT '0' COMMENT '课程结束时间',
  `AddTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '添加时间',
  `CmdStartNums` int(11) NOT NULL DEFAULT '0' COMMENT '开始命令发送次数',
  `CmdStartTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '开始命令发送时间',
  `CourseStarted` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否上报已启动 0-未启动 1-已启动',
  `CmdEndNums` int(11) NOT NULL DEFAULT '0' COMMENT '结束命令发送次数',
  `CmdEndTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '结束命令发送时间',
  `CourseEnded` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否上报已结束 0-未上报 1-已上报',
  `ManualStopTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '手动停止时间',
  `CourseStatus` enum('creat','active','stop','fault','end') NOT NULL DEFAULT 'creat' COMMENT '课程状态（生成-creat  上课-active  停止-stop  故障-fault 结束-end）',
  `CourseFault` varchar(1024) NOT NULL DEFAULT '' COMMENT '故障原因',
  `ModTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '最后修改时间',
  PRIMARY KEY (`CourseId`),
  KEY `ClassId` (`ClassId`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='双师课堂课程（定时生成）';


-- ----------------------------------------------------
-- Table structure for `nccs`.`DoubleClassCourseDevice`
-- ----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DoubleClassCourseDevice`;
CREATE TABLE `nccs`.`DoubleClassCourseDevice` (
  `Id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
  `ClassId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂ID',
  `CourseId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂课程ID',
  `SpaceID` int(11) NOT NULL DEFAULT '0' COMMENT '教室（空间）ID',
  `SpaceName` varchar(255) NOT NULL DEFAULT '' COMMENT '教室（空间）名称',
  `DevId` varchar(255) NOT NULL DEFAULT '' COMMENT '设备ID',
  `ClassType` enum('lead','follow') NOT NULL DEFAULT 'lead' COMMENT '教室类型（lead - 主讲教室  follow - 辅讲教室）',
  `DeviceType` enum('main','slave') NOT NULL DEFAULT 'main' COMMENT '设备类型（main - 主控设备  slave - 从设备）',
  `CmdStart` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否发送启动命令 0-未发送 1-已发送',
  `CmdStartTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '发送启动命令时间',
  `CmdStartNums` int(11) NOT NULL DEFAULT '0' COMMENT '发送启动命令次数',
  `CmdStartReport` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否上报处于双师课堂 0-未处于 1-已处于',
  `CmdStartReportTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '设备上报处于双师课堂时间',
  `CmdEnd` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否发送停止命令 0-未发送 1-已发送',
  `CmdEndTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '发送停止命令时间',
  `CmdEndNums` int(11) NOT NULL DEFAULT '0' COMMENT '发送停止命令次数',
  `CmdEndReport` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否上报不处于双师课堂 0-未上报 1-已上报',
  `CmdEndReportTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '设备上报不处于双师课堂时间',
  PRIMARY KEY (`Id`),
  UNIQUE KEY `CourseDev` (`CourseId`,`DevId`),
  KEY `ClassId` (`ClassId`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='双师课堂课程设备';

-- ------------------------------------------
-- Table structure for `nccs`.`DoubleClassSpace`
-- ------------------------------------------
CREATE TABLE `DoubleClassSpace` (
  `SpaceID` int(11) NOT NULL DEFAULT '0' COMMENT '教室（空间）ID',
  `DeviceMain` varchar(255) NOT NULL DEFAULT '' COMMENT '主设备ID',
  `DeviceSlave` varchar(255) NOT NULL DEFAULT '' COMMENT '辅设备ID',
  `CreateTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '创建时间',
  PRIMARY KEY (`SpaceID`),
  UNIQUE KEY `devices` (`DeviceMain`,`DeviceSlave`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='双师课堂教室（空间）';

-- ------------------------------------------
-- Table structure for `nccs`.`DoubleClassLog`
-- ------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DoubleClassLog`;
CREATE TABLE `nccs`.`DoubleClassLog` (
  `Id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'ID',
  `ClassId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂ID',
  `CourseId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂课程ID',
  `DevId` varchar(255) NOT NULL DEFAULT '' COMMENT '设备ID',
  `Title` varchar(255) NOT NULL DEFAULT '' COMMENT '事件标题',
  `Detail` varchar(4096) NOT NULL DEFAULT '' COMMENT '详细数据',
  `AddTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '添加时间',
  PRIMARY KEY (`Id`),
  KEY `CourseId` (`CourseId`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='双师课堂运行详细日志';


-- -----------------------------------------------------
-- Table `nccs`.`TaskTemplate`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`TaskTemplate` ;

CREATE TABLE IF NOT EXISTS `nccs`.`TaskTemplate` (
  `idTaskTemplate` INT(11) NOT NULL AUTO_INCREMENT,
  `TemplateName` VARCHAR(50) NOT NULL DEFAULT '',
  `Enabled` TINYINT(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`idTaskTemplate`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlaySessions`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlaySessions` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlaySessions` (
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL DEFAULT '0',
  `SessionName` VARCHAR(50) NOT NULL,
  `SessionType` TINYINT(4) NULL DEFAULT NULL COMMENT '0: automatic broadcast task\n1: player created task\n2: manually played task\n10:BW803 player created task',
  `Priority` TINYINT(4) NULL DEFAULT NULL,
  `Status` TINYINT(4) NOT NULL DEFAULT '0',
  `CircleLength` INT(11) NOT NULL DEFAULT '0',
  `ClassID` INT(11) NULL DEFAULT NULL,
  `PlayerID` VARCHAR(50) NULL DEFAULT NULL,
  `Parent` SMALLINT(5) UNSIGNED NULL DEFAULT NULL,
  `BrdMode` INT(11) NULL DEFAULT NULL,
  `MemberMode` TINYINT(1) NOT NULL DEFAULT '0',
  `StreamType` TINYINT(4) UNSIGNED NOT NULL DEFAULT '1' COMMENT 'Stream Type: \n1: valid 0: invalid\nBit 0: audio\nBit1: Video',
  `SysEnabled` TINYINT(4) NULL DEFAULT NULL,
  `RfDevCtrl` BINARY(16) NULL DEFAULT NULL,
  `Owner` INT(11) NULL DEFAULT NULL,
  `PlayMode` TINYINT(4) NULL DEFAULT '0' COMMENT '0: Sequential Playing',
  `AudioGain` TINYINT(4) NULL DEFAULT '0',
  `Template` INT(11) NULL DEFAULT NULL,
  `ReceivingEndType` int(11) NOT NULL DEFAULT '1' COMMENT '0: 设备 1：空间，2：分组',
  `CreateSource` tinyint(4) NOT NULL DEFAULT '0' COMMENT '0表示本地。1表示汇聚平台。2表示云端。3表示第三方OpenAPI',
  PRIMARY KEY (`SessionID`),
  UNIQUE INDEX `SessionID_UNIQUE` (`SessionID` ASC),
  INDEX `Players` (`PlayerID` ASC),
  INDEX `SessionParent` (`Parent` ASC),
  INDEX `SessionMode` (`BrdMode` ASC),
  INDEX `SessionUser` (`Owner` ASC),
  INDEX `TaskTemplate_idx` (`Template` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlaySessionTime`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlaySessionTime` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlaySessionTime` (
  `ScheduleID` INT(11) NOT NULL AUTO_INCREMENT,
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL,
  `WeekDay` TINYINT(4) NOT NULL,
  `PlayTime` DATETIME NOT NULL,
  `TempFlag` TINYINT(4) NOT NULL DEFAULT 0,
  `Length` INT(11) NOT NULL DEFAULT 0,
  `TaskType` varchar(255) NOT NULL DEFAULT '' COMMENT '采播推流类型 video-视频推流   audio-音频推流',
  `AudioChannels` varchar(255) NOT NULL DEFAULT '' COMMENT '采播开启音频通道（存储通道下标数组）',
  `LocalMedia` varchar(4096) NOT NULL DEFAULT '' COMMENT '采播任务选择的设备媒体信息',
  `KeyZones` varchar(255) NOT NULL DEFAULT '' COMMENT '801 805 定时任务按键分区',
  `EntryID` INT(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`ScheduleID`),
  UNIQUE INDEX `SesTime_UNIQUE` (`SessionID` ASC, `WeekDay` ASC, `PlayTime` ASC),
  INDEX `Schsessionid` (`SessionID` ASC),
  CONSTRAINT `sIDForeignKey`
    FOREIGN KEY (`SessionID`)
    REFERENCES `nccs`.`PlaySessions` (`SessionID`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COMMENT = 'Auto broadcast playing schedules';


-- -----------------------------------------------------
-- Table `nccs`.`EventModel`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`EventModel` ;

CREATE TABLE IF NOT EXISTS `nccs`.`EventModel` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `Manufacturer` VARCHAR(31) NOT NULL,
  `Model` VARCHAR(31) NOT NULL,
  `Magic` INT(11) UNSIGNED NOT NULL,
  PRIMARY KEY (`id`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`Event`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Event` ;

CREATE TABLE IF NOT EXISTS `nccs`.`Event` (
  `Id` INT(11) NOT NULL AUTO_INCREMENT,
  `Name` VARCHAR(31) NOT NULL,
  `StartTask` SMALLINT(6) UNSIGNED NULL DEFAULT NULL,
  `EndTask` SMALLINT(6) UNSIGNED NULL DEFAULT NULL,
  `Config` VARBINARY(64) NOT NULL COMMENT '事件配置',
  `Model` INT(11) NOT NULL COMMENT '型号',
  `Version` INT(11) NOT NULL DEFAULT '0' COMMENT '版本号:自动生成，前端禁止操作',
  PRIMARY KEY (`Id`),
  INDEX `model_idx` (`Model` ASC),
  INDEX `event_end_fkn_idx` (`EndTask` ASC),
  INDEX `event_start_fkn_idx` (`StartTask` ASC),
  CONSTRAINT `EventModel`
    FOREIGN KEY (`Model`)
    REFERENCES `nccs`.`EventModel` (`id`),
  CONSTRAINT `event_end_fkn`
    FOREIGN KEY (`EndTask`)
    REFERENCES `nccs`.`PlaySessions` (`SessionID`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `event_start_fkn`
    FOREIGN KEY (`StartTask`)
    REFERENCES `nccs`.`PlaySessions` (`SessionID`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`MediaFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`MediaFiles` ;

CREATE TABLE IF NOT EXISTS `nccs`.`MediaFiles` (
  `MediaID` INT(11) NOT NULL AUTO_INCREMENT,
  `FileName` VARCHAR(128) NULL DEFAULT NULL,
  `FileSize` BIGINT(20) NULL DEFAULT NULL,
  `TotalTime` INT(11) NOT NULL DEFAULT '0',
  `FileFmt` INT(11) NULL DEFAULT NULL COMMENT '0: celt\n1: mp3\n2: ts\n3: mp4, mov',
  `BitRate` INT(11) NULL DEFAULT NULL,
  `VedioCodec` INT(11) NULL DEFAULT NULL COMMENT '0: h264\n1: mpeg4',
  `Height` INT(11) NULL DEFAULT NULL,
  `Width` INT(11) NULL DEFAULT NULL,
  `FrameRate` INT(11) NULL DEFAULT NULL,
  `AudioCodec` INT(11) NULL DEFAULT NULL COMMENT '0: celt\n1: mp3',
  `Channels` INT(11) NULL DEFAULT NULL,
  `SampleRate` INT(11) NULL DEFAULT NULL,
  `Parent` INT(11) NULL DEFAULT NULL,
  `Gain` TINYINT(4) NULL DEFAULT '0',
  `CreateTime` DATETIME NULL DEFAULT NULL,
  `FilePath` VARCHAR(256) NULL DEFAULT NULL,
  `Owner` INT(11) NULL DEFAULT NULL COMMENT 'sysfolder owner',
  `Sysfolder` TINYINT(4) NULL DEFAULT NULL COMMENT 'system create folder,not update or delete\n1:true',
  `Check` TINYINT(4) NOT NULL DEFAULT '0',
  `CreateSource` tinyint(4) NOT NULL DEFAULT '0' COMMENT '0表示本地。1表示汇聚平台。2表示云端。3表示第三方OpenAPI',
  PRIMARY KEY (`MediaID`),
  UNIQUE INDEX `ID_UNIQUE` (`MediaID` ASC),
  INDEX `MediaParent` (`Parent` ASC),
  INDEX `MediaUser_idx` (`Owner` ASC),
  CONSTRAINT `MediaParent`
    FOREIGN KEY (`Parent`)
    REFERENCES `nccs`.`MediaFiles` (`MediaID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;



-- -----------------------------------------------------
-- Table `nccs`.`PlayListFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayListFiles` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayListFiles` (
  `PlayListFIleId` INT(11) NOT NULL AUTO_INCREMENT,
  `FileID` INT(11) NULL DEFAULT NULL,
  `SequenceID` INT(11) NOT NULL,
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL,
  `Duration` INT(11) NULL DEFAULT '0',
  `KeyIndex` INT(11) NULL DEFAULT NULL,
  `PlayerID` VARCHAR(50) NULL DEFAULT NULL,
  PRIMARY KEY (`PlayListFIleId`),
  UNIQUE INDEX `SessionIDSeq` (`SessionID` ASC, `SequenceID` ASC),
  INDEX `SessionID` (`SessionID` ASC),
  INDEX `FileID` (`FileID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `nccs`.`PlayerKeys`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayerKeys` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayerKeys` (
  `PlayerKeyId` INT(11) NOT NULL AUTO_INCREMENT,
  `PlayerID` VARCHAR(50) NOT NULL,
  `Index` INT(11) NOT NULL,
  `GroupDisable` TINYINT(4) NULL DEFAULT '0',
  `DevDisable` TINYINT(4) NULL DEFAULT '0',
  `GroupID` INT(11) NULL DEFAULT NULL,
  `logic_class` INT(1) NOT NULL DEFAULT '0',
  `logic_class_id` INT(11) NULL DEFAULT NULL,
  `name` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`PlayerKeyId`),
  UNIQUE INDEX `PlayerIndex` (`PlayerID` ASC, `Index` ASC),
  INDEX `PlayerKey_PlayerID` (`PlayerID` ASC),
  INDEX `PlayerGroupID` (`GroupID` ASC),
  CONSTRAINT `PlayerGroupID`
    FOREIGN KEY (`GroupID`)
    REFERENCES `nccs`.`DevClasses` (`ClassID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `PlayerKey_PlayerID`
    FOREIGN KEY (`PlayerID`)
    REFERENCES `nccs`.`Players` (`PlayerID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlayerStatus`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayerStatus` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayerStatus` (
  `PlayerID` VARCHAR(50) NOT NULL,
  `SessionID` SMALLINT(5) UNSIGNED NULL DEFAULT '0',
  `ScheduleID` INT(11) NULL DEFAULT NULL,
  `IpAddress` VARCHAR(50) NULL DEFAULT NULL,
  `NetID` TINYINT(4) NULL DEFAULT NULL,
  `ActualSesID` INT(11) NULL DEFAULT NULL,
  `PlayPort` INT(11) NULL DEFAULT NULL,
  `PlayType` TINYINT(4) NULL DEFAULT NULL,
  PRIMARY KEY (`PlayerID`),
  INDEX `PlayerStatusPlayerID` (`PlayerID` ASC),
  INDEX `PlayerStatusSessionID` (`SessionID` ASC),
  INDEX `PlayerStatusScheduleID` (`ScheduleID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlayingSessions`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayingSessions` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayingSessions` (
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL,
  `PlayerID` VARCHAR(50) NULL DEFAULT NULL,
  `PlayingFileID` INT(11) NULL DEFAULT NULL,
  `MultiPort` INT(11) NULL DEFAULT NULL,
  `CircleLength` INT(11) NULL DEFAULT NULL,
  `CurrFileProgress` INT(11) NULL DEFAULT NULL,
  `CurrTotalProgress` INT(11) NULL DEFAULT NULL,
  `Priority` TINYINT(4) NULL DEFAULT NULL,
  `Pause` TINYINT(4) NOT NULL DEFAULT '0',
  `ScheduleID` INT(11) NULL DEFAULT NULL,
  `BrdMode` INT(11) NULL DEFAULT NULL,
  `SesType` TINYINT(4) NULL DEFAULT '0',
  `StreamType` TINYINT(4) UNSIGNED NULL DEFAULT '1',
  `PlayBeginTime` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`SessionID`),
  UNIQUE INDEX `SessionID_UNIQUE` (`SessionID` ASC),
  UNIQUE INDEX `PlayerID_UNIQUE` (`PlayerID` ASC),
  INDEX `Session` (`SessionID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`ProjectorType`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`ProjectorType` ;

CREATE TABLE IF NOT EXISTS `nccs`.`ProjectorType` (
  `Type` varchar(50) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
  `PoweroffDelay` INT(11) NOT NULL,
  `CheckBit` INT(11) NOT NULL,
  `StopBit` INT(11) NOT NULL,
  `DataBit` INT(11) NOT NULL,
  `BaudRate` INT(11) NOT NULL,
  `CmdOpen` VARCHAR(255) NOT NULL,
  `CmdClose` VARCHAR(255) NOT NULL,
  `CmdFromPc` VARCHAR(255) NOT NULL,
  `CmdFromVideo` VARCHAR(255) NOT NULL,
  `CmdChannel3` varchar(255) NOT NULL DEFAULT '',
  `CmdChannel4` varchar(255) NOT NULL DEFAULT '',
  `ChangedFromLocal` tinyint(1) NOT NULL DEFAULT 0 COMMENT '值为1时表示投影机是否被用户在本地服务器修改过(本地添加的型号和本地修改过的投影机型号)',
  PRIMARY KEY (`Type`),
  UNIQUE INDEX `Type_UNIQUE` (`Type` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PwrDisplaySet`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PwrDisplaySet` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PwrDisplaySet` (
  `PwrID` TINYINT(4) NOT NULL,
  `Name` VARCHAR(45) NULL DEFAULT NULL,
  `Type` TINYINT(4) NULL DEFAULT NULL,
  `Icon` VARCHAR(64) NULL DEFAULT NULL,
  PRIMARY KEY (`PwrID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`Scene`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Scene` ;

CREATE TABLE IF NOT EXISTS `nccs`.`Scene` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(45) NOT NULL DEFAULT '' COMMENT '名称',
  `icon` VARCHAR(45) NOT NULL DEFAULT '' COMMENT '图标',
  `control_list` VARCHAR(2048) NOT NULL DEFAULT '{}' COMMENT '操作清单',
  `product_match_preg` VARCHAR(128) NOT NULL DEFAULT '' COMMENT '产品匹配列表',
  PRIMARY KEY (`id`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COMMENT = '设备场景表';

-- -----------------------------------------------------
-- Table `nccs`.`SectionTable`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SectionTable` ;

CREATE TABLE `nccs`.`SectionTable`  (
  `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  `zone_id` int NOT NULL DEFAULT '0' COMMENT '校区ID',
  `section` int(11) NOT NULL COMMENT '节次num',
  `alias` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '节次别名，如第一节',
  `start` time(0) NOT NULL DEFAULT '00:00:00',
  `end` time(0) NOT NULL DEFAULT '23:59:59',
  `is_deleted` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否已删除',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `SectionTableIndexNum` (`section`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;


-- -----------------------------------------------------
-- Table `nccs`.`SensorProduct`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SensorProduct` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SensorProduct` (
  `product_id` INT(11) NOT NULL,
  `name` VARCHAR(64) NOT NULL,
  `mod_bus` SMALLINT(6) NOT NULL,
  `vendor_id` INT(11) NOT NULL,
  `update_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `from_cloud` tinyint(1) NOT NULL DEFAULT 0,
  UNIQUE INDEX `product_index` USING BTREE (`product_id` ASC, `vendor_id` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SensorVendor`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SensorVendor` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SensorVendor` (
  `id` INT(11) UNSIGNED NOT NULL,
  `name` VARCHAR(64) NOT NULL,
  `update_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `from_cloud` tinyint(1) NOT NULL DEFAULT 0,
  PRIMARY KEY (`id`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SessionCtrlList`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SessionCtrlList` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SessionCtrlList` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
  `SessionID` SMALLINT(6) NOT NULL,
  `SubID` INT(11) NOT NULL,
  `State` INT(11) NULL DEFAULT NULL,
  `Action` INT(11) NULL DEFAULT NULL,
  `DataState` INT(1) NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `SesSubID_UNIQUE` USING BTREE (`SessionID` ASC, `SubID` ASC),
  INDEX `SessionID` USING BTREE (`SessionID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;





-- -----------------------------------------------------
-- Table `nccs`.`SubNetwork`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SubNetwork` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SubNetwork` (
  `idSubNetwork` INT(11) NOT NULL,
  `NetMask` VARCHAR(50) NULL DEFAULT NULL,
  `IpAddress` VARCHAR(50) NULL DEFAULT NULL,
  `UniCast` TINYINT(4) NOT NULL DEFAULT 0,
  PRIMARY KEY (`idSubNetwork`),
  UNIQUE INDEX `idSubNetwork_UNIQUE` (`idSubNetwork` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SystemLog`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SystemLog` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SystemLog` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `ip` VARCHAR(16) NULL DEFAULT NULL,
  `result` INT(11) NOT NULL,
  `username` VARCHAR(255) NULL DEFAULT NULL,
  `title1` VARCHAR(255) NULL DEFAULT NULL,
  `title2` VARCHAR(255) NULL DEFAULT NULL,
  `type` VARCHAR(64) NOT NULL COMMENT 'controller name',
  `action` VARCHAR(64) NOT NULL COMMENT 'action name',
  `detail` VARCHAR(2048) NULL DEFAULT NULL,
  `parameter_detail` varchar(4096) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NULL DEFAULT NULL,
  PRIMARY KEY (`id`,`at`),
  INDEX `systemlog_idx` (`username` ASC, `type` ASC, `ip` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`Timetable`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Timetable` ;

CREATE TABLE `nccs`.`Timetable`  (
  `Id` int(11) NOT NULL AUTO_INCREMENT,
  `TermName` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '学年-学期。如：2023-2024-1',
  `Week` int(3) NOT NULL DEFAULT 0 COMMENT '上课周次',
  `WeekDay` tinyint(4) NOT NULL DEFAULT 0 COMMENT '上课星期',
  `StartSection` int(11) NOT NULL DEFAULT 0 COMMENT '开始节次',
  `EndSection` int(11) NOT NULL DEFAULT 0 COMMENT '结束节次',
  `ZoneID` int(11) NOT NULL DEFAULT 0 COMMENT '校区ID',
  `SpaceID` int(11) NOT NULL DEFAULT 0 COMMENT '空间ID',
  `UserId` int(11) NOT NULL DEFAULT 0 COMMENT '老师在idste系统ID',
  `CourseName` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '课程名称',
  `Class` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '班级名称',
  `Major` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '专业',
  `Type` enum('normal','temporary') CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT 'normal' COMMENT 'normal:正课\ntemporary:临课',
  `OneTime` tinyint(4) NOT NULL DEFAULT 0,
  `Sync` tinyint(4) NOT NULL DEFAULT 0,
  PRIMARY KEY (`Id`) USING BTREE,
  UNIQUE INDEX `only`(`TermName`, `Week`, `WeekDay`, `StartSection`, `EndSection`, `SpaceID`, `UserId`) USING BTREE,
  INDEX `userIdKey_idx`(`UserId`) USING BTREE,
  INDEX `deviceId_idx`(`SpaceID`) USING BTREE,
  INDEX `table_idx`(`SpaceID`, `UserId`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '课表' ROW_FORMAT = Dynamic;


-- -----------------------------------------------------
-- Table `nccs`.`TimeTablePowerLog`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`TimeTablePowerLog` ;

CREATE TABLE IF NOT EXISTS `nccs`.`TimeTablePowerLog` (
  `ID` int(11) NOT NULL AUTO_INCREMENT,
  `TimeTableID` int(11) NOT NULL DEFAULT '0' COMMENT '课表ID',
  `WeekDay` tinyint(4) NOT NULL DEFAULT '0' COMMENT '上课星期',
  `Start` varchar(255) NOT NULL DEFAULT '' COMMENT '开始时间',
  `End` varchar(255) NOT NULL DEFAULT '' COMMENT '结束时间',
  `SpaceID` int(11) NOT NULL DEFAULT '0' COMMENT '联动教室ID',
  `SpaceName` varchar(255) NOT NULL DEFAULT '' COMMENT '联动教室名称',
  `DeviceID` varchar(255) NOT NULL DEFAULT '' COMMENT '设备ID',
  `AutoPower` int(11) NOT NULL DEFAULT '0' COMMENT '0-自动关机  1-自动开机',
  `AutoTime` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '执行时间',
  `SendCode` int(11) NOT NULL DEFAULT '0' COMMENT '联动开机下发结果',
  `CheckTime` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '最后检测时间',
  `CheckNum` int(11) NOT NULL DEFAULT '0' COMMENT '检测次数',
  `CheckResult` varchar(255) NOT NULL DEFAULT '' COMMENT '检查结果',
  `AddTime` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '日志生成时间',
  PRIMARY KEY (`ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='课表联动开关机日志';


-- -----------------------------------------------------
-- Table `nccs`.`TimetableV1`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`TimetableV1` ;

CREATE TABLE IF NOT EXISTS `nccs`.`TimetableV1` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `Dev_Name` VARCHAR(50) NOT NULL,
  `User_Flag` VARCHAR(20) NOT NULL DEFAULT '',
  `User_Name` VARCHAR(32) NOT NULL DEFAULT '' COMMENT '\"tmp_phone\"临时课需要填写用户姓名',
  `Zone` VARCHAR(32) NOT NULL DEFAULT '',
  `CourseName` VARCHAR(64) NOT NULL DEFAULT '',
  `TermName` VARCHAR(32) NOT NULL DEFAULT '',
  `SectionStart` INT(11) NOT NULL DEFAULT '0',
  `SectionEnd` INT(11) NOT NULL DEFAULT '0',
  `WeekStart` INT(11) NOT NULL DEFAULT '1',
  `WeekEnd` INT(11) NOT NULL DEFAULT '9999',
  `WeekDay` INT(11) NOT NULL DEFAULT '6',
  `WeekType` ENUM('single', 'double', 'all') NOT NULL DEFAULT 'all',
  `Active` ENUM('yes', 'no') NOT NULL DEFAULT 'yes' COMMENT '是否活动，活动状态的课表会用于设备控制',
  `Type` ENUM('normal', 'tmp_usersn', 'tmp_phone') NOT NULL DEFAULT 'normal' COMMENT 'normal: 正式课\ntmp_usersn:用户工号临时课\ntmp_phone:手机号临时课',
  PRIMARY KEY (`ID`),
  INDEX `TimetableV1_idx2` (`Dev_Name` ASC),
  INDEX `TimetableV1_idx1` (`User_Flag` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;



-- ----------------------------
-- Table `nccs`.DeviceScenes
-- ----------------------------
DROP TABLE IF EXISTS `DeviceScenes`;
CREATE TABLE IF NOT EXISTS `nccs`.`DeviceScenes`  (
  `DeviceSceneID` int(11) NOT NULL AUTO_INCREMENT,
  `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '',
  `SceneID` int(11) NOT NULL,
  `SceneName` varchar(96) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '场景名称不能超过32个汉字',
  `SceneCtrlList` varchar(4096) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '场景控制列表，为json字符串',
  PRIMARY KEY (`DeviceSceneID`) USING BTREE,
  UNIQUE INDEX `device_scene`(`DeviceID`, `SceneID`) USING BTREE COMMENT '一个设备不能有两个相同id的场景'
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;



-- -----------------------------------------------------
-- Table `nccs`.`tmp_DelMediaFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`tmp_DelMediaFiles` ;

CREATE TABLE IF NOT EXISTS `nccs`.`tmp_DelMediaFiles` (
  `filepath` VARCHAR(256) NOT NULL,
  PRIMARY KEY (`filepath`))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`tmp_result`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`tmp_result` ;

CREATE TABLE IF NOT EXISTS `nccs`.`tmp_result` (
  `idtmp_result` INT(11) NULL DEFAULT NULL)
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`tmp_storage`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`tmp_storage` ;

CREATE TABLE IF NOT EXISTS `nccs`.`tmp_storage` (
  `key` VARCHAR(32) NOT NULL,
  `strv` VARCHAR(64) NULL DEFAULT NULL,
  `intv` INT(11) NULL DEFAULT NULL,
  `datev` DATETIME NULL DEFAULT NULL,
  `expire` INT(10) NULL DEFAULT NULL,
  PRIMARY KEY (`key`))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `nccs`.`PcCallDirectories`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PcCallDirectories` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PcCallDirectories`  (
  `DirectoryID` int(10) NOT NULL AUTO_INCREMENT,
  `Name` varchar(63) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
  `SessionID` int(10) NOT NULL,
  `IsDefault` tinyint(1) NOT NULL,
  PRIMARY KEY (`DirectoryID`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

-- -----------------------------------------------------
-- Table `nccs`.`PcCallBindFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PcCallBindFiles` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PcCallBindFiles`  (
  `BindID` int(10) NOT NULL AUTO_INCREMENT,
  `FileID` int(10) NOT NULL,
  `SessionID` int(10) NOT NULL,
  `Parent` int(10) NOT NULL,
  `OrderIndex` int(10) NOT NULL COMMENT '播放顺序',
  PRIMARY KEY (`BindID`) USING BTREE,
  UNIQUE INDEX `parent_file`(`FileID`, `Parent`) USING BTREE COMMENT '一个目录下面不出现两个一样的文件'
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

-- -----------------------------------------------------
-- Table `nccs`.`EnvironmentalParameters`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`EnvironmentalParameters` ;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvironmentalParameters`  (
  `ID` int(10) NOT NULL AUTO_INCREMENT,
  `ProtocolFieldName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '参数在协议中对应的字段',
  `Name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '参数名称',
  `Unit` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '单位',
  `ExactValue` float(8, 3) UNSIGNED NOT NULL DEFAULT 1.000 COMMENT '精确度',
  `from_cloud` tinyint(1) NOT NULL DEFAULT 0,
  PRIMARY KEY (`ID`) USING BTREE,
  UNIQUE INDEX `protocolFieldName`(`ProtocolFieldName`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;



-- -----------------------------------------------------
-- Table `nccs`.`EnvControlInfo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`EnvControlInfo` ;
CREATE TABLE `nccs`.`EnvControlInfo`  (
  `ID` int(10) NOT NULL AUTO_INCREMENT,
  `Type` int(10) NOT NULL COMMENT '策略类型。1：环境策略',
  `Name` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '策略的名称',
  `Conditions` varchar(4096) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '{}' COMMENT '策略条件。json格式',
  `Duration` int(10) NOT NULL COMMENT '满足条件以后需要持续该时间长度才执行任务',
  `Operation` varchar(4096) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL  DEFAULT '{}' COMMENT '该策略需要执行的操作。json格式',
  `Weekday` int(10) NOT NULL COMMENT '表示周几。bit1-bit6表示周一到周六，bit0表示周天',
  `EntryTimeType` int(10) NOT NULL COMMENT '生效时间类型 0：表示每天中哪个时间范围执行该策略 1：表示每天中哪个时间点执行该策略',
  `StartTime` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '与EndTime一起作用，比如：08:00:00 EntryTimeType = 0时有效',
  `EndTime` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '与StartTime一起作用，比如：12:00:00 EntryTimeType = 0时有效',
  `TimeSpot` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '比如：09:00:00 EntryTimeType = 2时有效',
  `ReceivingEndType` int(10) NOT NULL DEFAULT '1' COMMENT '0: 设备 1：空间，2：分组',
  PRIMARY KEY (`ID`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

-- -----------------------------------------------------
-- Table `nccs`.`RfConfig`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`RfConfig` ;
CREATE TABLE IF NOT EXISTS `nccs`.`RfConfig`  (
    `ID` int NOT NULL AUTO_INCREMENT,
    `PwrID` int(11) NOT NULL,
    `Name` varchar(45) DEFAULT NULL COMMENT '物联名称',
    `ChildType` int(11) NOT NULL  COMMENT '物联二级类型',
    `DevID` varchar(50) NOT NULL DEFAULT '0' COMMENT '设备ID',
    `VendorID` int(11) NOT NULL DEFAULT '0' COMMENT '厂家ID',
    `ProductID` int(11) NOT NULL DEFAULT '0' COMMENT '产品类型ID',
    `URI` varchar(255) NOT NULL DEFAULT '',
    PRIMARY KEY (`ID`),
    UNIQUE KEY `uniqueIndex` (`PwrID`,`DevID`) USING BTREE,
    KEY `devIdIndex` (`DevID`) USING BTREE
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='物联配置表基于设备';

-- -----------------------------------------------------
-- Table `nccs`.`SessionCtrlListType`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SessionCtrlListType` ;
CREATE TABLE IF NOT EXISTS `nccs`.`SessionCtrlListType`  (
    `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
    `SessionID` smallint(6) NOT NULL,
    `ChildType` int(11) NOT NULL,
    `State` int(11) DEFAULT NULL,
    `Action` int(11) DEFAULT NULL,
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE KEY `SesSubID_UNIQUE` (`SessionID`,`ChildType`) USING BTREE,
    KEY `SessionID` (`SessionID`) USING BTREE
    )ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

-- -----------------------------------------------------
-- Table `nccs`.`RfChildType`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`RfChildType` ;

CREATE TABLE IF NOT EXISTS `nccs`.`RfChildType` (
    `ID` int(11) NOT NULL AUTO_INCREMENT COMMENT '子类型',
    `RfType` int(11) NOT NULL COMMENT '父类型',
    `Name` varchar(255) NOT NULL COMMENT '子类型名称',
    `IsDefault` tinyint(1) NOT NULL COMMENT '0：正常子类，1：默认子类',
    `CreateTime` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `UpdateTime` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    `IsDeleted` tinyint(1) NOT NULL DEFAULT '0',
    PRIMARY KEY (`ID`)
    ) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC;

-- -----------------------------------------------------
-- Table `nccs`.`SessionNoRfCtrlList`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SessionNoRfCtrlList` ;
CREATE TABLE IF NOT EXISTS   `nccs`.`SessionNoRfCtrlList` (
    `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
    `SessionID` smallint(6) NOT NULL,
    `SubID` int(11) NOT NULL COMMENT '256:中控，257:屏蔽仪，258:电子时钟',
    `State` int(11) DEFAULT NULL,
    `Action` int(11) DEFAULT NULL,
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE KEY `SesSubID_Type_UNIQUE` (`SessionID`,`SubID`) USING BTREE,
    KEY `SessionID` (`SessionID`) USING BTREE
    ) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;

-- ----------------------------
-- Table structure for Graphics
-- ----------------------------
DROP TABLE IF EXISTS `Graphics`;
CREATE TABLE `Graphics`  (
  `ID` int(10) NOT NULL AUTO_INCREMENT COMMENT '模板唯一键值',
  `Name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '模板的名称',
  `Content` longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '模板的内容',
  `Url` varchar(1028) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '访问模板的url',
  `Status` tinyint(1) NOT NULL DEFAULT 0 COMMENT '模板是否已经通过审核0：待审核，1：审核通过，2：审核被拒绝',
  `LinkedDev` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '模板关联的设备的ID，一般是演讲型教室的模板',
  `Sign` int(10) UNSIGNED NOT NULL DEFAULT 0 COMMENT '表示是否有更新',
  `UpdateAt` timestamp(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '更新时间',
  PRIMARY KEY (`ID`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;



-- ----------------------------
-- Table structure for GraphicSessions
-- ----------------------------
DROP TABLE IF EXISTS `GraphicSessions`;
CREATE TABLE `GraphicSessions` (
    `id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '图文任务ID',
    `name` varchar(255) NOT NULL,
    `priority` tinyint(5) unsigned NOT NULL DEFAULT '30',
    `forced` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '1表示强制接收，0表示不强制接收',
    `start_time` datetime NOT NULL COMMENT '任务开始时间',
    `stop_time` datetime NOT NULL COMMENT '任务结束时间',
    `start_time_hms` time NOT NULL COMMENT '存放start_time字段的时分秒',
    `time_style` tinyint(4) NOT NULL DEFAULT '0' COMMENT '重复周期，按照bit位重复,bit0表示周天',
    `status` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '0表示禁止状态，1表示停止状态，2表示运行状态',
    `resource_id` int(10) unsigned NOT NULL COMMENT '图文资源ID',
    `owner` int(11) NOT NULL COMMENT '创建者ID',
    `update_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    `create_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_status_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '任务状态更新时间',
    `receiving_end_type` int(11) NOT NULL DEFAULT '1',
    PRIMARY KEY (`id`),
    KEY `start_time_hms_index` (`start_time_hms`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `nccs`.`OAuthUser` ;
CREATE TABLE IF NOT EXISTS `nccs`.`OAuthUser` (
    `ID` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键',
    `Name` varchar(255) NOT NULL COMMENT '用户名',
    `Phone` varchar(50) NOT NULL COMMENT '电话',
    `Info` varchar(255) NOT NULL COMMENT '主要信息',
    `ForPlat` int(11) NOT NULL DEFAULT 0 COMMENT '0:服务器用户1:设备端用户',
    PRIMARY KEY (`ID`),
    UNIQUE KEY `ID` (`ID`) USING BTREE,
    KEY `Phone` (`Phone`) USING BTREE
    ) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `nccs`.`OAuthAppInfo` ;
CREATE TABLE IF NOT EXISTS `nccs`.`OAuthAppInfo` (
    `Id` int(11) NOT NULL AUTO_INCREMENT,
    `OAuthUserID` int(11) NOT NULL COMMENT '第三方用户ID',
    `AppID` varchar(255) NOT NULL,
    `AppSecret` varchar(255) NOT NULL,
    `IsAllPrivilege` bigint(1) NOT NULL DEFAULT '0' COMMENT '0:非全部，1：全部权限',
    `Privilege` varchar(255) NOT NULL COMMENT '以“,”分割的权限字符串',
    `RedirectUrl` varchar(255) NOT NULL COMMENT '回调地址',
    `SyncValue` int(11) NOT NULL DEFAULT 1 COMMENT '数据更新自动加1',
    PRIMARY KEY (`Id`) USING BTREE,
    UNIQUE KEY `AppID` (`AppID`) USING BTREE
    ) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`OAuthToken` ;
CREATE TABLE  IF NOT EXISTS `nccs`.`OAuthToken` (
    `AppID` varchar(256) NOT NULL,
    `Token` varchar(255) NOT NULL,
    `TimeOut` datetime NOT NULL COMMENT '过期时间',
    UNIQUE KEY `AppID` (`AppID`) USING BTREE
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `nccs`.`DevicePower` ;
CREATE TABLE IF NOT EXISTS   `nccs`.`DevicePower` (
    `DeviceID` varchar(255) NOT NULL COMMENT '设备ID',
    `StatisticDay` date NOT NULL COMMENT '日期',
    `SubID` int(11) NOT NULL COMMENT '0-31 表示物联。 256,257,258 表示中控、投影、二路投影',
    `PowerConsumed` int(11) NOT NULL COMMENT '单位w',
    `UsedTime` int(11) DEFAULT NULL COMMENT '单位s',
    `SubType` int(11) NOT NULL DEFAULT '0' COMMENT '设备类型，中控、投影仪1、投影1、与SubID 相同。 物联设备 为 RfType',
    `SpaceID` int(11) NOT NULL DEFAULT '0',
    `RfChildID` int(11) NOT NULL DEFAULT '0',
    UNIQUE KEY `StatisticDay` (`StatisticDay`,`DeviceID`,`SpaceID`,`SubID`,`SubType`)
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8;


-- ----------------------------
-- Table structure for LogicClasses
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`LogicClasses`;
CREATE TABLE `nccs`.`LogicClasses` (
  `id` int(10) NOT NULL AUTO_INCREMENT,
  `name` varchar(256) NOT NULL DEFAULT '' COMMENT '逻辑分区名称（不重复 使用其他表数据生成的名称）',
  `extend_name` varchar(255) NOT NULL DEFAULT '' COMMENT '逻辑分区扩展名称（用于显示的名称）',
  `type`  tinyint NOT NULL DEFAULT 1 COMMENT '类型 1-采播设备逻辑分区',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='设备逻辑分区';

DROP TABLE IF EXISTS `nccs`.`Firmware`;
CREATE TABLE `nccs`.`Firmware` (
  `auto_id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '自增ID',
  `id` bigint(20) UNSIGNED NOT NULL COMMENT '资源编号',
  `name` varchar(256) NOT NULL,
  `chip` varchar(32) NOT NULL DEFAULT '',
  `arch` varchar(255) NOT NULL DEFAULT '' COMMENT '指令集架构',
  `pre` varchar(255) NOT NULL DEFAULT '',
  `md5` varchar(255) NOT NULL DEFAULT '',
  `hash` varchar(255) NOT NULL DEFAULT '' COMMENT '文件hash值',
  `notes` varchar(1024) NOT NULL DEFAULT '',
  `version` int(11) NOT NULL DEFAULT 0,
  `version_v2` varchar(255) NOT NULL DEFAULT '',
  `os` varchar(32) NOT NULL DEFAULT '' COMMENT '安装包/升级包支持的系统的名称',
  `os_version` varchar(32) NOT NULL DEFAULT '' COMMENT '固件os版本',
  `app_name` varchar(255) NOT NULL DEFAULT '' COMMENT 'app名称',
  `pkg_name` varchar(255) NOT NULL DEFAULT '' COMMENT 'app包名',
  `file_path` varchar(128) NOT NULL DEFAULT '',
  `forPlat` tinyint(1) NOT NULL DEFAULT 0 COMMENT '表示应用到哪个平台。0：嵌入式设备 1：电脑助手iDsteCare',
  `download_progress` tinyint(4) UNSIGNED NOT NULL DEFAULT 0 COMMENT '下载进度，0-100',
  `modify_by` int(11) UNSIGNED NULL DEFAULT NULL COMMENT '修改人用户ID',
  `update_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`auto_id`) USING BTREE,
  UNIQUE INDEX `uidx_id`(`id`) USING BTREE COMMENT 'id索引',
  UNIQUE KEY `nameIndex` (`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `nccs`.`EnvDataCh2oV2`;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvDataCh2oV2`  (
    `id` int(10) NOT NULL AUTO_INCREMENT,
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    `SpaceID` int(11) NOT NULL DEFAULT '0',
    UNIQUE INDEX `INDEX`(`ReportDate`, `SpaceID`, `DeviceID`) USING BTREE,
    PRIMARY KEY (`id`)
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataCo2V2`;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvDataCo2V2`  (
    `id` int(10) NOT NULL AUTO_INCREMENT,
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    `SpaceID` int(11) NOT NULL DEFAULT '0',
    UNIQUE INDEX `INDEX`(`ReportDate`, `SpaceID`, `DeviceID`) USING BTREE,
    PRIMARY KEY (`id`)
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataHumidityV2`;
CREATE TABLE  IF NOT EXISTS `nccs`.`EnvDataHumidityV2`  (
    `id` int(10) NOT NULL AUTO_INCREMENT,
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    `SpaceID` int(11) NOT NULL DEFAULT '0',
    UNIQUE INDEX `INDEX`(`ReportDate`, `SpaceID`, `DeviceID`) USING BTREE,
    PRIMARY KEY (`id`)
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataInfraredV2`;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvDataInfraredV2`  (
    `id` int(10) NOT NULL AUTO_INCREMENT,
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '设备ID',
    `Val` int(11) NOT NULL,
    `SpaceID` int(11) NOT NULL DEFAULT '0',
    UNIQUE INDEX `INDEX`(`ReportDate`, `SpaceID`, `DeviceID`) USING BTREE,
    PRIMARY KEY (`id`)
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataLightV2`;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvDataLightV2`  (
    `id` int(10) NOT NULL AUTO_INCREMENT,
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    `SpaceID` int(11) NOT NULL DEFAULT '0',
    UNIQUE INDEX `INDEX`(`ReportDate`, `SpaceID`, `DeviceID`) USING BTREE,
    PRIMARY KEY (`id`)
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataNoiseV2`;
CREATE TABLE  IF NOT EXISTS `nccs`.`EnvDataNoiseV2`  (
    `id` int(10) NOT NULL AUTO_INCREMENT,
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    `SpaceID` int(11) NOT NULL DEFAULT '0',
    UNIQUE INDEX `INDEX`(`ReportDate`, `SpaceID`, `DeviceID`) USING BTREE,
    PRIMARY KEY (`id`)
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataPm2dot5V2`;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvDataPm2dot5V2`  (
    `id` int(10) NOT NULL AUTO_INCREMENT,
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    `SpaceID` int(11) NOT NULL DEFAULT '0',
    UNIQUE INDEX `INDEX`(`ReportDate`, `SpaceID`, `DeviceID`) USING BTREE,
    PRIMARY KEY (`id`)
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataRadarV2`;
CREATE TABLE IF NOT EXISTS  `nccs`.`EnvDataRadarV2`  (
    `id` int(10) NOT NULL AUTO_INCREMENT,
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '设备ID',
    `Val` int(11) NOT NULL,
    `SpaceID` int(11) NOT NULL DEFAULT '0',
    UNIQUE INDEX `INDEX`(`ReportDate`, `SpaceID`, `DeviceID`) USING BTREE,
    PRIMARY KEY (`id`)
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataTemperatureV2`;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvDataTemperatureV2`  (
    `id` int(10) NOT NULL AUTO_INCREMENT,
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    `SpaceID` int(11) NOT NULL DEFAULT '0',
    UNIQUE INDEX `INDEX`(`ReportDate`, `SpaceID`, `DeviceID`) USING BTREE,
    PRIMARY KEY (`id`)
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataTvocV2`;
CREATE TABLE IF NOT EXISTS  `nccs`.`EnvDataTvocV2`  (
    `id` int(10) NOT NULL AUTO_INCREMENT,
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    `SpaceID` int(11) NOT NULL DEFAULT '0',
    UNIQUE INDEX `INDEX`(`ReportDate`, `SpaceID`, `DeviceID`) USING BTREE,
    PRIMARY KEY (`id`)
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;


DROP TABLE IF EXISTS `nccs`.`Student` ;
CREATE TABLE IF NOT EXISTS `nccs`.`Student` (
  `Number` varchar(255) NOT NULL DEFAULT '' COMMENT '学生证号码',
  `Name` varchar(255) NOT NULL DEFAULT '' COMMENT '姓名',
  `College` varchar(255) NOT NULL DEFAULT '' COMMENT '学院',
  `Grade` int(11) NOT NULL DEFAULT '0' COMMENT '年级(毕业年份)',
  `Class` varchar(255) NOT NULL DEFAULT '' COMMENT '专业班级',
  `Mobile` varchar(255) NOT NULL DEFAULT '' COMMENT '手机号码',
  PRIMARY KEY (`Number`),
  KEY `mobile` (`Mobile`),
  KEY `name` (`Name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='学生信息对接表';

DROP TABLE IF EXISTS `nccs`.`RegisterUser` ;
CREATE TABLE IF NOT EXISTS `nccs`.`RegisterUser` (
  `UserAccount` varchar(255) NOT NULL DEFAULT '' COMMENT '用户账号（下划线开头的是系统用户）',
  `Phone` varchar(255) NOT NULL DEFAULT '' COMMENT '电话号码',
  `User_ID` int(11) NOT NULL DEFAULT '-5' COMMENT '系统用户ID',
  `UserType` enum('student','teacher','other') NOT NULL DEFAULT 'student' COMMENT '用户类型（student-学生 teacher-教职工 other-其他人员）',
  `UserName` varchar(255) NOT NULL DEFAULT '' COMMENT '注册姓名',
  `UserCollege` varchar(255) NOT NULL DEFAULT '' COMMENT '注册学院',
  `UserGrade` int(11) NOT NULL DEFAULT '2019' COMMENT '注册年级',
  `UserClass` varchar(255) NOT NULL DEFAULT '' COMMENT '注册班级',
  `UserNumber` varchar(255) NOT NULL DEFAULT '' COMMENT '注册学工号',
  `AddTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '注册时间',
  `ActiveTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '最后参与时间',
  `MatchStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '学生匹配状态(0-未匹配 1-匹配成功 -1-匹配失败)',
  `MatchID` int(11) NOT NULL DEFAULT '0' COMMENT '匹配ID（匹配当时 user或student 表中的ID）',
  `MatchName` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配姓名',
  `MatchCollege` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学院',
  `MatchGrade` int(11) NOT NULL DEFAULT '2019' COMMENT '匹配年级',
  `MatchClass` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配班级',
  `MatchNumber` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学工号',
  `MatchMobile` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配手机号码',
  `AuditStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '审核状态（0-未审核  1-审核已通过 -1-审核未通过）',
  `AuditUserID` int(11) NOT NULL DEFAULT '0' COMMENT '审核用户ID',
  `AuditUserName` varchar(255) NOT NULL DEFAULT '' COMMENT '审核用户姓名',
  `AuditTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '审核时间',
  `ReserveTotal` int(11) NOT NULL DEFAULT '0' COMMENT '教室预约次数',
  `ReservePass` int(11) NOT NULL DEFAULT '0' COMMENT '教室预约成功次数',
  `ReserveCancel` int(11) NOT NULL DEFAULT '0' COMMENT '教室预约取消次数',
  `ReserveUse` int(11) NOT NULL DEFAULT '0' COMMENT '预约使用次数',
  `ReserveActive` int(11) NOT NULL DEFAULT '0' COMMENT '教室预约有效数量（列表可见）',
  `ReserveHistory` int(11) NOT NULL DEFAULT '0' COMMENT '历史记录数',
  PRIMARY KEY (`UserAccount`),
  KEY `phone` (`Phone`),
  KEY `userID` (`User_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='注册用户';

DROP TABLE IF EXISTS `nccs`.`DeviceReserve` ;
CREATE TABLE IF NOT EXISTS `nccs`.`DeviceReserve` (
  `ID` int(11) NOT NULL AUTO_INCREMENT COMMENT '预约ID',
  `User_ID` int(11) NOT NULL DEFAULT '-5' COMMENT '系统用户的用户ID',
  `UserMobile` varchar(255) NOT NULL DEFAULT '' COMMENT '用户手机号码',
  `UserType` enum('student','other','teacher') NOT NULL DEFAULT 'student' COMMENT '用户类型',
  `UserName` varchar(255) NOT NULL DEFAULT '' COMMENT '姓名',
  `UserCollege` varchar(255) NOT NULL DEFAULT '' COMMENT '所属学院',
  `UserGrade` int(11) NOT NULL DEFAULT '2019' COMMENT '所属年级',
  `UserClass` varchar(255) NOT NULL DEFAULT '' COMMENT '所属班级',
  `UserNumber` varchar(255) NOT NULL DEFAULT '' COMMENT '学工号',
  `MatchStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '匹配状态(0-未匹配 1-匹配成功 -1-匹配失败)',
  `MatchID` int(11) NOT NULL DEFAULT '0' COMMENT '匹配ID（匹配当时 user或student 表中的ID）',
  `MatchName` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配姓名',
  `MatchCollege` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学院',
  `MatchGrade` int(11) NOT NULL DEFAULT '2019' COMMENT '匹配年级',
  `MatchClass` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配班级',
  `MatchNumber` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学工号',
  `MatchMobile` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配手机号码',
  `ClassID` int(11) NOT NULL DEFAULT '0' COMMENT '设备分区ID',
  `ClassName` varchar(255) NOT NULL DEFAULT '' COMMENT '设备分区名称（教学楼）',
  `SpaceID` int(11) NOT NULL,
  `DeviceID` varchar(255)  DEFAULT '' COMMENT '设备ID',
  `DeviceName` varchar(255) NOT NULL DEFAULT '' COMMENT '设备名称（教室）',
  `DeviceDescription` varchar(255) NOT NULL DEFAULT '' COMMENT '设备位置',
  `DeviceExt` varchar(255) NOT NULL DEFAULT '' COMMENT '扩展设备ID,英文逗号分割（双师课堂一个教室有两个设备）',
  `StartTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '开始时间',
  `EndTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '结束时间',
  `Reason` varchar(255) NOT NULL DEFAULT '' COMMENT '预约原因',
  `ApplyTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '申请时间',
  `ModifyTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '修改时间',
  `AuditStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '审核状态（0-未审核  1-审核未通过 2-审核已通过 -1-审核已过期）',
  `AuditUserID` int(11) NOT NULL DEFAULT '0' COMMENT '审核用户ID',
  `AuditUserName` varchar(255) NOT NULL DEFAULT '' COMMENT '审核用户姓名',
  `AuditTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '审核时间',
  `AuditInfo` varchar(255) NOT NULL DEFAULT '' COMMENT '审核备注信息',
  `CancelStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '取消状态（0-未取消  1-用户自己取消 2-管理员取消）',
  `CancelUserID` int(11) NOT NULL DEFAULT '0' COMMENT '取消用户ID （管理员取消才有值）',
  `CancelUserName` varchar(255) NOT NULL DEFAULT '' COMMENT '取消用户姓名（管理员取消才有值）',
  `CancelTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '取消时间',
  `CancelReason` varchar(255) NOT NULL DEFAULT '' COMMENT '取消原因',
  `UseQrCode` varchar(255) NOT NULL DEFAULT '' COMMENT '反向扫码二维码',
  `UseStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '使用状态（0-未使用 1-已使用）',
  `UseDeviceID` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否使用设备(0-未使用 1-已使用)',
  `UseDeviceExt` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否使用扩展设备(0-未使用 1-已使用)',
  `UseCount` int(11) NOT NULL DEFAULT '0' COMMENT '使用次数',
  `UseTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '使用时间',
  `UseDevice` varchar(255) NOT NULL DEFAULT '' COMMENT '使用设备ID',
  PRIMARY KEY (`ID`),
  KEY `mobile` (`UserMobile`),
  KEY `number` (`UserNumber`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='教室预约';

DROP TABLE IF EXISTS `nccs`.`DeviceReserveHistory` ;
CREATE TABLE IF NOT EXISTS `nccs`.`DeviceReserveHistory` (
  `ID` int(11) NOT NULL COMMENT '预约ID',
  `User_ID` int(11) NOT NULL DEFAULT '-5' COMMENT '系统用户的用户ID',
  `UserMobile` varchar(255) NOT NULL DEFAULT '' COMMENT '用户手机号码',
  `UserType` enum('student','teacher','other') NOT NULL DEFAULT 'student' COMMENT '用户类型',
  `UserName` varchar(255) NOT NULL DEFAULT '' COMMENT '姓名',
  `UserCollege` varchar(255) NOT NULL DEFAULT '' COMMENT '所属学院',
  `UserGrade` int(11) NOT NULL DEFAULT '2019' COMMENT '所属年级',
  `UserClass` varchar(255) NOT NULL DEFAULT '' COMMENT '所属班级',
  `UserNumber` varchar(255) NOT NULL DEFAULT '' COMMENT '学工号',
  `MatchStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '匹配状态(0-未匹配 1-匹配成功 -1-匹配失败)',
  `MatchID` int(11) NOT NULL DEFAULT '0' COMMENT '匹配ID（匹配当时 user或student 表中的ID）',
  `MatchName` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配姓名',
  `MatchCollege` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学院',
  `MatchGrade` int(11) NOT NULL DEFAULT '2019' COMMENT '匹配年级',
  `MatchClass` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配班级',
  `MatchNumber` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学工号',
  `MatchMobile` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配手机号码',
  `ClassID` int(11) NOT NULL DEFAULT '0' COMMENT '设备分区ID',
  `ClassName` varchar(255) NOT NULL DEFAULT '' COMMENT '设备分区名称（教学楼）',
  `SpaceID` int(11) NOT NULL,
  `DeviceID` varchar(255) NOT NULL DEFAULT '' COMMENT '设备ID',
  `DeviceName` varchar(255) NOT NULL DEFAULT '' COMMENT '设备名称（教室）',
  `DeviceExt` varchar(255) NOT NULL DEFAULT '' COMMENT '扩展设备ID,英文逗号分割（双师课堂一个教室有两个设备）',
  `DeviceDescription` varchar(255) NOT NULL DEFAULT '' COMMENT '设备位置',
  `StartTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '开始时间',
  `EndTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '结束时间',
  `Reason` varchar(255) NOT NULL DEFAULT '' COMMENT '预约原因',
  `ApplyTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '申请时间',
  `ModifyTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '修改时间',
  `AuditStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '审核状态（0-未审核  1-审核已通过 -1-审核未通过）',
  `AuditUserID` int(11) NOT NULL DEFAULT '0' COMMENT '审核用户ID',
  `AuditUserName` varchar(255) NOT NULL DEFAULT '' COMMENT '审核用户姓名',
  `AuditTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '审核时间',
  `AuditInfo` varchar(255) NOT NULL DEFAULT '' COMMENT '审核备注信息',
  `CancelStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '取消状态（0-未取消  1-用户自己取消 2-管理员取消）',
  `CancelUserID` int(11) NOT NULL DEFAULT '0' COMMENT '取消用户ID （管理员取消才有值）',
  `CancelUserName` varchar(255) NOT NULL DEFAULT '' COMMENT '取消用户姓名（管理员取消才有值）',
  `CancelTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '取消时间',
  `CancelReason` varchar(255) NOT NULL DEFAULT '' COMMENT '取消原因',
  `UseQrCode` varchar(255) NOT NULL DEFAULT '' COMMENT '反向扫码二维码',
  `UseStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '使用状态（0-未使用 1-已使用）',
  `UseDeviceID` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否使用设备(0-未使用 1-已使用)',
  `UseDeviceExt` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否使用扩展设备(0-未使用 1-已使用)',
  `UseCount` int(11) NOT NULL DEFAULT '0' COMMENT '使用次数',
  `UseTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '使用时间',
  `UseDevice` varchar(255) NOT NULL DEFAULT '' COMMENT '使用设备ID',
  PRIMARY KEY (`ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='教室预约历史数据';

DROP TABLE IF EXISTS `nccs`.`DevUsedStatusV2`;
CREATE TABLE `nccs`.`DevUsedStatusV2` (
   `id` int(11) NOT NULL  AUTO_INCREMENT,
  `DevID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '融合终端，音视频直转播终端，mic等设备的ID(因为mic可能从一个设备挪到另一个设备使用所以单独为mic创建记录)',
  `Type` int(10) NOT NULL COMMENT '用于区分设备类型(0:融合终端 1:空调 2:电源 10:音视频直转播终端 11:麦克风 12:网关设备  )',
  `Status` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'offline:离线 online:在线 pwrOn:开机 pwrOff:关机 using:使用中 isPushing:推流中 takeout:取离',
  `UpdateDate` date NOT NULL DEFAULT '2022-04-19' COMMENT 'mic和充电桩上报该状态时的时间',
  `Count` int(10) NOT NULL COMMENT '设备切换为该状态的次数',
  UNIQUE INDEX `Dev_Status_Date`(`DevID`, `Status`, `UpdateDate`, `Type`) USING BTREE,
  PRIMARY KEY (`id`)
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`MicPhoneList`;
CREATE TABLE `nccs`.`MicPhoneList`  (
  `id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'mic的id',
  `name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT 'mic的名称',
  `mic_type` int(32) NOT NULL DEFAULT 0 COMMENT '麦克风类型',
  `last_dev_id` varchar(255) NOT NULL DEFAULT '' COMMENT '最近一次归属的设备ID',
  `charge_count` int(32) NOT NULL DEFAULT 0 COMMENT '充电次数',
  `update_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `delete_time` bigint(20) NOT NULL DEFAULT '0' COMMENT '删除时间',
  `used_time` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`MicStubList`;
CREATE TABLE `nccs`.`MicStubList`  (
  `id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '充电桩id',
  `name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '充电桩名称',
  `stub_type` int(32) NOT NULL DEFAULT 0 COMMENT '充电桩类型',
  `last_dev_id` varchar(255) NOT NULL DEFAULT '' COMMENT '最近一次归属的设备ID',
  `update_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `delete_time` bigint(20) NOT NULL DEFAULT '0' COMMENT '删除时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;


DROP TABLE IF EXISTS `nccs`.`SessionHistory`;
CREATE TABLE  `nccs`.`SessionHistory` (
  `SessionID` smallint(6) NOT NULL COMMENT '任务ID',
  `SessionStreamType` tinyint(4) UNSIGNED NOT NULL COMMENT '任务内容类型，与任务表相同',
  `SourceMode` tinyint(4) NOT NULL COMMENT '来源方式',
  `SessionType` tinyint(4) NOT NULL COMMENT '任务类型，与任务表相同',
  `SessionName` varchar(50) NOT NULL COMMENT '任务名称',
  `ScheduleID` int(11) NOT NULL COMMENT '执行时间ID，手动任务为0',
  `ScheduleTime` time NOT NULL COMMENT '执行时间',
  `Status` tinyint(4) NOT NULL COMMENT '执行状态 0：待执行，1:执行中，2：执行成功，3：执行失败',
  `HistoryDate` date NOT NULL COMMENT '任务当日时间',
  `PlayerID` varchar(50) NOT NULL DEFAULT '' COMMENT '采播设备ID',
  UNIQUE KEY `SessionID` (`SessionID`,`ScheduleID`,`HistoryDate`,`ScheduleTime`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `nccs`.`ReportData`;
CREATE TABLE  `nccs`.`ReportData` (
  `table_id` int(11) NOT NULL COMMENT '报表ID',
  `row_id` varchar(255) NOT NULL COMMENT '报表周期 例：按月分组 ‘2022-01’，‘2022-02’',
  `header_column_id` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '子项关联ID',
  `base_id` varchar(255) NOT NULL COMMENT '按设备统计含义为 ：device_id 。按学校统计 含义为 ：school_id 按学校-设备统计：school_id-device-id ',
  `val` varchar(255) NOT NULL COMMENT '具体数据值',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  UNIQUE KEY `table_id` (`table_id`,`row_id`,`header_column_id`,`base_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `nccs`.`DevOfflineTime`;
CREATE TABLE `nccs`.`DevOfflineTime`  (
  `dev_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备ID',
  `type` int(11) NOT NULL COMMENT '用于区分设备类型(0:融合终端 1:空调 2:电源 10:音视频直转播终端 11:麦克风 12:网关设备  )',
  `offline_time_unix` int(11) NOT NULL COMMENT '离线时间戳',
  `update_at` timestamp(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '日期和时间',
  UNIQUE INDEX `school_dev`(`dev_id`, `type`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`ThirdClassDevices`;
CREATE TABLE `nccs`.`ThirdClassDevices`  (
    `third_class_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
    `dev_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
    `app_id` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
    UNIQUE INDEX `third_class_id_index`(`third_class_id`, `app_id`) USING BTREE,
    UNIQUE INDEX `dev_id_index`(`dev_id`, `app_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`UserIcCardSync`;
CREATE TABLE `nccs`.`UserIcCardSync` (
  `DevID` varchar(255) NOT NULL DEFAULT '' COMMENT '设备ID',
  `OnlineTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '上线时间',
  `SyncValue` bigint(20) NOT NULL DEFAULT '-1' COMMENT '同步字',
  `SyncNum` int(11) NOT NULL DEFAULT '0' COMMENT '同步数量',
  `SyncIcData` varchar(4096) NOT NULL DEFAULT '' COMMENT '同步IC卡数据（用于调试）',
  `SyncTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '同步时间',
  `SyncCount` int(11) NOT NULL DEFAULT '0' COMMENT '同步总次数',
  `UpdateSyncValue` bigint(20) NOT NULL DEFAULT '-1' COMMENT '更新的同步字',
  `UpdateSyncNum` int(11) NOT NULL DEFAULT '0' COMMENT '更新的同步数量',
  `UpdateSyncTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '更新的同步时间',
  `UpdateCount` int(11) NOT NULL DEFAULT '0' COMMENT '更新的总次数',
  PRIMARY KEY (`DevID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='用户IC卡数据同步给设备';




DROP TABLE IF EXISTS `nccs`.`Monitor`;
CREATE TABLE `nccs`.`Monitor`  (
   `id` int(11) NOT NULL AUTO_INCREMENT,
   `space_id` int(11) NOT NULL DEFAULT 0,
   `name` varchar(255) NOT NULL DEFAULT '',
   `url` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '主码流',
   `sub_url` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '副码流',
   `update_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0),
   `create_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0),
   PRIMARY KEY (`id`) USING BTREE,
   KEY `space_id` (`space_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '监控' ROW_FORMAT = Dynamic;



DROP TABLE IF EXISTS `nccs`.`RemotePC`;
CREATE TABLE `nccs`.`RemotePC`  (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `ip` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '',
    `ctrl_pwd` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '',
    `view_pwd` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '',
    `port` int(255) NOT NULL DEFAULT 0,
    `space_id` int(11) NOT NULL,
    `update_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0),
    `create_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0),
    PRIMARY KEY (`id`) USING BTREE,
    INDEX `space_id`(`space_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '远程电脑控制' ROW_FORMAT = Dynamic;



DROP TABLE IF EXISTS `nccs`.`Space`;
CREATE TABLE `nccs`.`Space`  (
     `id` int(11) NOT NULL AUTO_INCREMENT,
     `location` varchar(255) NOT NULL DEFAULT '' COMMENT '空间位置',
     `name` varchar(255) NOT NULL DEFAULT '' COMMENT '课表对接名称',
     `space_type` int(11) NOT NULL DEFAULT '0' COMMENT '空间类型',
     `class_type` int(11) NOT NULL DEFAULT '0' COMMENT '教室类型',
     `play_audio` tinyint(1) NOT NULL DEFAULT '0' COMMENT '能否播放音频',
     `play_video` tinyint(1) NOT NULL DEFAULT '0' COMMENT '能否播放视频',
     `play_graphic` tinyint(1) NOT NULL DEFAULT '0' COMMENT ' 能否播放图文',
     `ctrl_rf` tinyint(1) NOT NULL DEFAULT '0' COMMENT '能否控制物联',
     `master_dev_id` varchar(50) NOT NULL DEFAULT '' COMMENT '主设备ID',
     `zone_id` int NOT NULL DEFAULT '0' COMMENT '校区ID',
     `seats` int NOT NULL DEFAULT '0' COMMENT '座位数',
     `dev_description` varchar(255) NOT NULL DEFAULT '' COMMENT '教室设备描述',
     `record_config` varchar(600) NOT NULL DEFAULT '' COMMENT '录播配置',
     `timetable_power_off_to` tinyint(1) NOT NULL DEFAULT 0 COMMENT '联动课表关机命令发送对象。0：中控 1：电脑助手',
     `is_deleted` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否已删除',
     `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
     `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '空间表' ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`SpaceAndDevice`;
CREATE TABLE `nccs`.`SpaceAndDevice`  (
      `dev_id` varchar(50) NOT NULL COMMENT '设备ID',
      `space_id` int(11) NOT NULL COMMENT '空间ID',
      `enable_audio` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0:禁用，1：启用',
      `enable_video` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0:禁用，1：启用',
      `enable_rf` tinyint(1) NOT NULL DEFAULT '1' COMMENT '0:禁用，1：启用 默认启用',
      `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
      `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`dev_id`) USING BTREE,
    UNIQUE INDEX `space_id`(`space_id`, `dev_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;



DROP TABLE IF EXISTS `nccs`.`SignalSourceChannel`;
CREATE TABLE `SignalSourceChannel`(
    `id`                int(11) NOT NULL AUTO_INCREMENT,
    `space_id`          int(11) NOT NULL DEFAULT 0 COMMENT '空间id',
    `projector_channel` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '投影仪通道',
    `preview_channel`   varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '预览通道',
    `update_time`       datetime NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0),
    `create_time`       datetime  NOT NULL DEFAULT CURRENT_TIMESTAMP(0),
    PRIMARY KEY (`id`) USING BTREE,
    INDEX `space_id` (`space_id`) USING BTREE
) ENGINE = InnoDB CHARSET = utf8 COLLATE = utf8_general_ci COMMENT ='投影仪和预览信号源通道配置表' ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`BrdModeAndPartitionNode`;
CREATE TABLE `nccs`.`BrdModeAndPartitionNode`  (
   `id` int(11) NOT NULL AUTO_INCREMENT,
   `brd_mode_id` int(11) NOT NULL COMMENT '模式ID',
   `partition_id` int(11) NOT NULL COMMENT '逻辑分区ID',
   PRIMARY KEY (`id`) USING BTREE,
   UNIQUE INDEX `logical_partition_id`(`partition_id`, `brd_mode_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '模式接收成员空间表' ROW_FORMAT = DYNAMIC;

DROP TABLE IF EXISTS `nccs`.`GraphicAndPartitionNode`;
CREATE TABLE `nccs`.`GraphicAndPartitionNode`  (
   `id` int(11) NOT NULL AUTO_INCREMENT,
   `session_id` int(11) NOT NULL,
   `partition_id` int(11) NOT NULL,
   PRIMARY KEY (`id`) USING BTREE,
   UNIQUE INDEX `session_id`(`session_id`, `partition_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '图文任务空间表' ROW_FORMAT = DYNAMIC;

DROP TABLE IF EXISTS `nccs`.`Partition`;
CREATE TABLE `nccs`.`Partition`  (
     `id` int(11) NOT NULL AUTO_INCREMENT,
     `name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '',
     `type` tinyint(1) NOT NULL COMMENT '是否为物理分区：0：逻辑分区，1：物理分区',
     `update_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0),
     `create_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0),
     `is_deleted` tinyint(1) NOT NULL DEFAULT 0,
     PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '逻辑分区组' ROW_FORMAT = DYNAMIC;


DROP TABLE IF EXISTS `nccs`.`PartitionNode`;
CREATE TABLE `nccs`.`PartitionNode`  (
     `id` int(11) NOT NULL AUTO_INCREMENT,
     `p_id` int(11) NOT NULL DEFAULT 0,
     `name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '',
     `node_type` int(11) NOT NULL DEFAULT 0,
     `partition_id` int(11) NOT NULL DEFAULT 0,
     `space_id` int(11) NOT NULL DEFAULT 0 COMMENT '空间ID',
     `order_number` int(11) NOT NULL DEFAULT 0,
     `update_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0),
     `create_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0),
     PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '逻辑分区' ROW_FORMAT = DYNAMIC;


INSERT INTO `Partition`(`name`,type) VALUES('默认分区组',0);


INSERT INTO `PartitionNode`(`name`,partition_id) SELECT '全部',id FROM `Partition`  limit 1 ;


DROP TABLE IF EXISTS `nccs`.`SessionAndPartitionNode`;
CREATE TABLE `nccs`.`SessionAndPartitionNode`  (
   `id` int(11) NOT NULL AUTO_INCREMENT,
   `session_id` int(11) NOT NULL,
   `partition_id` int(11) NOT NULL,
   `key_index` int(11) NOT NULL DEFAULT '0',
   `node_disabled` int(11) NOT NULL DEFAULT '0',
   PRIMARY KEY (`id`) USING BTREE,
   UNIQUE INDEX `session_id`(`session_id`, `partition_id`, `key_index`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '任务空间表' ROW_FORMAT = DYNAMIC;


DROP TABLE IF EXISTS `nccs`.`UserAndPartitionNode`;
CREATE TABLE `nccs`.`UserAndPartitionNode` (
   `id` int(11) NOT NULL AUTO_INCREMENT,
   `user_id` int(11) NOT NULL,
   `partition_id` int(11) NOT NULL,
   `pri` tinyint(1) NOT NULL DEFAULT '0' COMMENT 'bit0: 用户可以使用的设备\\nbit1: 用户可以管理的设备',
   PRIMARY KEY (`id`) USING BTREE,
   UNIQUE KEY `session_id` (`user_id`,`partition_id`) USING BTREE
) ENGINE=InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '用户分区表' ROW_FORMAT = DYNAMIC;

DROP TABLE IF EXISTS `nccs`.`CLKMode`;
CREATE TABLE `nccs`.`CLKMode`  (
  `id` int(10) NOT NULL AUTO_INCREMENT,
  `name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '电子时钟任务名称',
  `start_time` datetime(0) NOT NULL COMMENT '模式开始时间',
  `start_entry_id` int(11) NOT NULL DEFAULT 0 COMMENT '模式开始时间在cron中的entry id',
  `end_time` datetime(0) NOT NULL COMMENT '模式结束时间。以unix时间戳形式下发。type=0时，该值为0；type=3时，是考试的结束时间；type=1或者type=2时，表示模式结束的绝对时间。',
  `end_entry_id` int(11) NOT NULL DEFAULT 0 COMMENT '模式结束时间在cron中的entry id',
  `priority` int(11) NOT NULL COMMENT '任务优先级',
  `mode_array` json NOT NULL COMMENT '电子时钟模式,一个数组，json格式。每个元素包含了电子时钟id，电子时钟的模式(0：普通模式，显示年月日时分秒 1：中考模式，显示”距离中考还有xx天” 2：高考模式，显示“距离高考还有xx天” 3：普通考试模式，显示”距离考试结束还有xx分钟”)。',
  `receive_member_type` int(11) NOT NULL DEFAULT 1 COMMENT '任务接收成员类型',
  `status` tinyint(2) NOT NULL DEFAULT 0 COMMENT '模式的状态',
  `owner` int(11) NOT NULL COMMENT '所属用户                                                         ',
  `update_at` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '更新该条数据的时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`CLKModeMember`;
CREATE TABLE `nccs`.`CLKModeMember`  (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `mode_id` int(11) NOT NULL COMMENT '模式id',
  `partition_id` int(11) NOT NULL COMMENT '空间或者分组id',
  `update_at` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0),
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE INDEX `taskid_memberid`(`partition_id`, `mode_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;


DROP TABLE IF EXISTS `nccs`.`LogicClassAndPartitionNode`;
CREATE TABLE `nccs`.`LogicClassAndPartitionNode`  (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
  `class_id` int(11) NOT NULL COMMENT '逻辑分区ID',
  `node_id` int(11) NOT NULL DEFAULT 0,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE INDEX `classDevIndex`(`class_id`, `node_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '逻辑分区设备' ROW_FORMAT = Dynamic;


-- ----------------------------
-- Table structure for MediaFileExtend
-- ----------------------------
DROP TABLE IF EXISTS `MediaFileExtend`;
CREATE TABLE `MediaFileExtend` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '媒体文件的id',
  `path` varchar(255) CHARACTER SET utf8 NOT NULL DEFAULT '' COMMENT '文件对端的路径',
  `peer_id` int(11) NOT NULL DEFAULT '0' COMMENT '对端的媒体文件id',
  `peer` tinyint(4) NOT NULL DEFAULT '0' COMMENT '0:本地;1:汇聚平台;2:云端',
  `update_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_index` (`peer_id`,`peer`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=57 DEFAULT CHARSET=latin1;

-- ----------------------------
-- Table structure for PlaySessionExtend
-- ----------------------------
DROP TABLE IF EXISTS `PlaySessionExtend`;
CREATE TABLE `PlaySessionExtend` (
  `SessionID` int(11) NOT NULL,
  `PeerSessionID` int(11) NOT NULL COMMENT '对端的任务关联ID',
  `Peer` tinyint(4) NOT NULL COMMENT '0表示本地。1表示汇聚平台。2表示云端。3表示第三方OpenAPI',
  `Description` varchar(512) CHARACTER SET utf8 NOT NULL DEFAULT '' COMMENT '该任务的描述信息',
  `SyncValue` int(11) NOT NULL DEFAULT '0',
  `AcceptTime` VARCHAR(20) NOT NULL DEFAULT '',
  `UpdateTime` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `CreateTime` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`SessionID`),
  UNIQUE KEY `peerSessoinUniqueIndex` (`PeerSessionID`,`Peer`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- ----------------------------
-- Table structure for PlayerPlayList
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`PlayerPlayList`;
CREATE TABLE `nccs`.`PlayerPlayList`  (
    `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT,
    `player_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备id',
    `list_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '列表名称',
    `files` varchar(20480) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '列表文件，json字符串',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `index`(`player_id`, `list_name`) USING BTREE COMMENT '联合索引'
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic COMMENT = '采播播放列表';

DROP TABLE IF EXISTS `nccs`.`CourseRecord`;
CREATE TABLE `nccs`.`CourseRecord`  (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `teacher_id` int(11) NOT NULL DEFAULT 0 COMMENT '教室ID',
    `teacher_name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '教师名称',
    `course` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '课程信息',
    `class_name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '教室名称',
    `space_id` int(11) NOT NULL DEFAULT '0' COMMENT '空间ID',
    `record_user_id` int(11) NOT NULL DEFAULT 0 COMMENT '评价人ID',
    `record_user_name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '评价人名称',
    `evaluation_id` int NOT NULL DEFAULT '0' COMMENT '评论ID',
    `content` varchar(1000) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '评论内容',
    `level` int(11) NOT NULL DEFAULT '0' COMMENT '星级',
    `update_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0),
    `create_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0),
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '巡课评论表' ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`CourseUser`;
CREATE TABLE `nccs`.`CourseUser`  (
      `id` int(11) NOT NULL AUTO_INCREMENT,
      `user_id` int(11) NOT NULL COMMENT '巡课老师ID',
      `course_user_id` int(11) NOT NULL COMMENT '被巡课老师ID',
      `update_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0),
      `create_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0),
      PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`CourseComment`;
CREATE TABLE `nccs`.`CourseComment`  (
     `id` int(11) NOT NULL AUTO_INCREMENT,
     `name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '',
     `content` varchar(1000) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '',
     `update_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0),
     `create_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0),
     PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '自定义评论表' ROW_FORMAT = DYNAMIC;

DROP TABLE IF EXISTS `nccs`.`DeviceSubStatus`;
CREATE TABLE `nccs`.`DeviceSubStatus` (
      `id` int(11) NOT NULL AUTO_INCREMENT,
      `dev_id` varchar(255) NOT NULL COMMENT '设备ID',
      `space_id` int(11) NOT NULL DEFAULT '0' COMMENT '空间ID',
      `sub_id` int(11) NOT NULL COMMENT '0-31 表示物联。 256,257,258 表示中控、投影、二路投影',
      `rf_child_type` int(11) NOT NULL DEFAULT '0' COMMENT '物联二级分类',
      `status` int(11) NOT NULL COMMENT '状态、-1 表示离线。其余状态由不同的类型决定字段含义',
      `user_id` int(11) NOT NULL DEFAULT '0' COMMENT '操作用户ID',
      `update_status_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '状态更新时间',
      `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
      PRIMARY KEY (`id`),
      KEY `index` (`dev_id`,`space_id`,`sub_id`,`rf_child_type`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='设备、以及子设备 状态更新存储表';

DROP TABLE IF EXISTS `nccs`.`DeviceUsedTime`;
CREATE TABLE `nccs`.`DeviceUsedTime` (
     `ID` int(11) NOT NULL AUTO_INCREMENT,
     `DeviceID` varchar(255) NOT NULL COMMENT '设备ID',
     `StatisticDay` date NOT NULL COMMENT '日期',
     `SubID` int(11) NOT NULL COMMENT '0-31 表示物联 256-257-258-259-260 表示中控、投影、二路投影、设备故障、用户上报故障开关机、261 表示设备离线情况统计',
     `StartTime` datetime NOT NULL COMMENT '开始时间',
     `EndTime` datetime NOT NULL COMMENT '结束时间',
     `UsedTime` int(11) NOT NULL COMMENT '单位s',
     `SpaceID` int(11) NOT NULL DEFAULT '0',
     `RfChildID` int(11) NOT NULL DEFAULT '0',
     `UserID` int(11) NOT NULL DEFAULT '0' COMMENT '使用人',
     PRIMARY KEY (`ID`),
     KEY `index` (`StatisticDay`,`DeviceID`,`SubID`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='设备使用时长统计表';
-- -----------------------------------------------------
-- Table structure for PrivilegeTemplate
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PrivilegeTemplate` ;
CREATE TABLE `nccs`.`PrivilegeTemplate`  (
    `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '用户权限模板id',
    `name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '模板名称',
    `privilege_list` varchar(4096) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '权限列表，权限之间用逗号分割',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '用户权限模板' ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataPm10V2`;
CREATE TABLE `nccs`.`EnvDataPm10V2`  (
  `id` int(10) NOT NULL AUTO_INCREMENT,
  `ReportDate` datetime NOT NULL,
  `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '设备ID',
  `Val` float(11, 2) NOT NULL,
  `SpaceID` int(11) NOT NULL DEFAULT 0,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE INDEX `INDEX`(`ReportDate`, `SpaceID`, `DeviceID`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = DYNAMIC;

-- -----------------------------------------------------
-- Table structure for Events
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Events`;
CREATE TABLE `nccs`.`Events`  (
    `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '事件id',
    `name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '事件名称',
    `event_type` tinyint(4) UNSIGNED NOT NULL DEFAULT 0 COMMENT '事件类型：0-无效，1-环境检测事件，2-GPIO事件，3-IOT事件，4-中控事件，5-状态检测事件',
    `duration` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '事件持续时间，单位：秒',
    `event_class` tinyint(4) UNSIGNED NOT NULL COMMENT '事件分类，1-设备特有事件，2-公共事件',
    `config` varchar(2048) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '公共事件配置，当even_classt为2时此项有效',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `name`(`name`) USING BTREE COMMENT '名称索引'
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '事件表' ROW_FORMAT = DYNAMIC;

-- -----------------------------------------------------
-- Table structure for DeviceAndEvent
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceAndEvent`;
CREATE TABLE `nccs`.`DeviceAndEvent`  (
    `dev_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备id',
    `event_id` int(11) UNSIGNED NOT NULL COMMENT '事件id',
    `logic` tinyint(4) UNSIGNED NOT NULL DEFAULT 1 COMMENT '逻辑关系，0-逻辑或，1-逻辑与',
    `triggers` varchar(2048) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '事件触发条件，json字符串',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    UNIQUE INDEX `index`(`dev_id`, `event_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '事件和设备绑定表' ROW_FORMAT = DYNAMIC;

-- ----------------------------
-- Table structure for StrategyInfo
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`StrategyInfo`;
CREATE TABLE `nccs`.`StrategyInfo`  (
  `ID` int(10) NOT NULL AUTO_INCREMENT,
  `Name` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '策略的名称',
  `StartDateTime` datetime NOT NULL COMMENT '策略开始运行时间。Y-m-d H:m:s格式',
  `EndDateTime` datetime NOT NULL COMMENT '策略运行结束时间。Y-m-d H:m:s格式',
  `Weekday` int(10) NOT NULL COMMENT '表示周几。bit1-bit6表示周一到周六，bit0表示周天',
  `Times` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '每天需要执行按事件执行具体操作的时间范围',
  `Operation` varchar(8092) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL DEFAULT '{}' COMMENT '该策略需要执行的操作。json格式',
  `ReceivingEndType` int(10) NOT NULL DEFAULT 1 COMMENT '0: 设备 1：空间，2：分组',
  `Status` tinyint(1) NOT NULL COMMENT '策略运行状态',
  `StartEntryID` int(10) NOT NULL DEFAULT 0,
  `EndEntryID` int(10) NOT NULL DEFAULT 0,
  `UpdateTime` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = DYNAMIC;

-- ----------------------------
-- Table structure for StrategyInfoAndPartitionNode
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`StrategyInfoAndPartitionNode`;
CREATE TABLE `nccs`.`StrategyInfoAndPartitionNode`  (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `strategy_id` int(10) NOT NULL COMMENT '环境策略ID',
  `partition_id` int(11) NOT NULL COMMENT '逻辑分区ID',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE INDEX `logical_partition_id`(`partition_id`, `strategy_id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '模式接收成员空间表' ROW_FORMAT = DYNAMIC;

-- ----------------------------
-- Table structure for StrategyAndEvent
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`StrategyAndEvent`;
CREATE TABLE `nccs`.`StrategyAndEvent`  (
  `id` int(10) NOT NULL AUTO_INCREMENT,
  `strategy_id` int(10) NOT NULL COMMENT '策略id',
  `event_id` int(11) UNSIGNED NOT NULL COMMENT '事件id',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE INDEX `strategy_event`(`strategy_id`, `event_id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8mb4 COLLATE = utf8mb4_general_ci ROW_FORMAT = DYNAMIC;

-- -----------------------------------------------------
-- Table structure for DeviceTotalEnergy
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceTotalEnergy`;
CREATE TABLE `nccs`.`DeviceTotalEnergy`  (
    `dev_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备id',
    `statistic_datetime` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '统计的日期时间，按天：\"2023-06-30\" 按小时：\"2023-06-30 10\"',
    `dev_energy` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '设备能耗，单位wh，总能耗=设备能耗+子设备能耗',
    `sub_energy` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '所有子设备的能耗和，单位wh，总能耗=设备能耗+子设备能耗',
    `dev_used_time` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '设备使用(开机)时长，单位s，总时长=设备开机时长+子设备开机时长',
    `sub_used_time` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '所有子设备的开机时长之和，单位s，总时长=设备开机时长+子设备开机时长',
    `statistic_type` tinyint(4) NOT NULL COMMENT '统计类型，0-按天，1-按小时',
    `reported` tinyint(4) NOT NULL DEFAULT 0 COMMENT '该条数据是否已上报过，0-未上报，1-已向云平台上报',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    UNIQUE INDEX `index`(`dev_id`, `statistic_datetime`) USING BTREE COMMENT '设备id和统计日期索引'
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '设备总能耗统计表' ROW_FORMAT = Dynamic;


-- ----------------------------
-- Table structure for ThirdClassQRCode
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`ThirdClassQRCode`;
CREATE TABLE `nccs`.`ThirdClassQRCode`  (
    `dev_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备id',
    `app_id` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'OpenAPI app id',
    `qrcode` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '第三方二维码',
    UNIQUE INDEX `index`(`dev_id`, `app_id`) USING BTREE COMMENT '设备id和app_id联合索引'
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '第三方教室二维码' ROW_FORMAT = Dynamic;


-- -----------------------------------------------------
-- Table structure for Asset
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Asset`;
CREATE TABLE IF NOT EXISTS `nccs`.`Asset`  (
    `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '资产编号，从1开始自增',
    `space_id` int(11) UNSIGNED NULL DEFAULT NULL COMMENT '资产归属空间',
    `sn` varchar(64) NOT NULL DEFAULT '' COMMENT '资产序列号，idste资产为设备ID',
    `introduction_time` varchar(32) NOT NULL DEFAULT '' COMMENT '资产启用时间，YYYY-MM-DD格式',
    `status` smallint(6) UNSIGNED NOT NULL DEFAULT 1 COMMENT '资产状态,1-在用，2-报废',
    `vendor` varchar(255) NOT NULL DEFAULT '' COMMENT '资产厂商',
    `asset_class` varchar(64) NOT NULL DEFAULT '' COMMENT '资产分类',
    `asset_type` varchar(64) NOT NULL DEFAULT '' COMMENT '资产具体型号',
    `num_prefix` varchar(64) NOT NULL DEFAULT '' COMMENT '资产编号前缀',
    `rated_life` smallint(6) UNSIGNED NOT NULL DEFAULT 0 COMMENT '资产额定寿命，单位：月',
    `supplier` varchar(255) NOT NULL DEFAULT '' COMMENT '供货商',
    `purchase_time` varchar(32) NOT NULL DEFAULT '' COMMENT '采购时间，YYYY-MM-DD格式',
    `purchase_amount` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '采购数量',
    `warranty_expire_time` varchar(32) NOT NULL DEFAULT '' COMMENT '资产质保过期时间，YYYY-MM-DD格式',
    `update_user` int(11) UNSIGNED NULL DEFAULT NULL COMMENT '记录更新用户ID',
    `is_deleted` tinyint(1) UNSIGNED NOT NULL DEFAULT 0 COMMENT '是否删除，0-未删除，1-已删除',
    `remark` varchar(1024) NOT NULL DEFAULT '' COMMENT '备注',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '记录更新时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '记录创建时间',
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `sn_index`(`sn`) USING BTREE COMMENT 'sn索引',
    INDEX `class_idx`(`asset_class`) USING BTREE COMMENT '分类索引',
    INDEX `type_idx`(`asset_type`) USING BTREE COMMENT '型号索引'
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '资产信息表' ROW_FORMAT = DYNAMIC;

-- -----------------------------------------------------
-- Table structure for AssetBatch
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`AssetBatch`;
CREATE TABLE IF NOT EXISTS `nccs`.`AssetBatch`  (
    `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键，批次ID',
    `vendor` varchar(255) NOT NULL DEFAULT '' COMMENT '资产厂商',
    `asset_class` varchar(64) NOT NULL DEFAULT '' COMMENT '资产分类',
    `asset_type` varchar(64) NOT NULL DEFAULT '' COMMENT '资产具体型号',
    `num_prefix` varchar(64) NOT NULL DEFAULT '' COMMENT '资产编号前缀',
    `rated_life` smallint(6) UNSIGNED NOT NULL DEFAULT 0 COMMENT '资产额定寿命，单位：月',
    `supplier` varchar(255) NOT NULL DEFAULT '' COMMENT '供货商',
    `purchase_time` varchar(32) NOT NULL DEFAULT '' COMMENT '采购时间，YYYY-MM-DD格式',
    `purchase_amount` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '采购数量',
    `warranty_expire_time` varchar(32) NOT NULL DEFAULT '' COMMENT '资产质保过期时间，YYYY-MM-DD格式',
    `update_user` int(11) UNSIGNED NULL DEFAULT NULL COMMENT '记录更新用户ID',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '资产批次录入表' ROW_FORMAT = DYNAMIC;

-- -----------------------------------------------------
-- Table structure for ICarePCBaseInfo
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`ICarePCBaseInfo`;
CREATE TABLE `nccs`.`ICarePCBaseInfo`  (
  `id` int NOT NULL AUTO_INCREMENT,
  `uuid` varchar(255) NOT NULL DEFAULT '' COMMENT 'pc设备uuid',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'idstecare名称',
  `version` varchar(255) NOT NULL DEFAULT '' COMMENT 'pc安装的icare的版本',
  `host_name` varchar(255) NOT NULL DEFAULT '' COMMENT 'pc主机名称',
  `os` varchar(255) NOT NULL DEFAULT '' COMMENT '操作系统版本',
  `hardware` varchar(2048) NOT NULL DEFAULT '' COMMENT '硬件信息',
  `network_card` varchar(4096) NOT NULL DEFAULT '' COMMENT '网卡信息列表。json格式',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE INDEX `uuid_index`(`uuid` ASC) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin ROW_FORMAT = Dynamic;

-- -----------------------------------------------------
-- Table structure for ICarePCConfig
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`ICarePCConfig`;
CREATE TABLE `nccs`.`ICarePCConfig`  (
  `id` int NOT NULL AUTO_INCREMENT,
  `uuid` varchar(255) NOT NULL COMMENT 'pc uuid',
  `name` varchar(255) NOT NULL COMMENT 'idstecare名称',
  `device_id` varchar(10) NOT NULL COMMENT '绑定设备id',
  `device_ip` varchar(15) NOT NULL COMMENT '绑定设备ip',
  `broker_ip` varchar(15) NOT NULL COMMENT '服务器ip',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE INDEX `uuid_index`(`uuid` ASC) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for AuxDevices
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`AuxDevices`;
CREATE TABLE `nccs`.`AuxDevices`  (
    `dev_id` varchar(55) NOT NULL DEFAULT '' COMMENT '附属设备ID',
    `proto_dev_name` varchar(16) NOT NULL DEFAULT '' COMMENT '附属设备协议设备类型',
    `last_bind_dev_id` varchar(55) NOT NULL DEFAULT '' COMMENT '附属设备最后绑定的中控id',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`dev_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '中控附属面板设备表' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for Theme
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`Theme`;
CREATE TABLE `nccs`.`Theme`  (
    `id` bigint(20) UNSIGNED NOT NULL COMMENT '云端id',
    `code` varchar(32) NOT NULL DEFAULT '' COMMENT '主题代码。格式：设备类型_编码，如：bc13_1',
    `base_path` varchar(64) NOT NULL DEFAULT '' COMMENT '主题解压基本路径。格式：设备类型_编码_主题版本，如：bc13_1_111',
    `name` varchar(255) NOT NULL DEFAULT '' COMMENT '主题名称',
    `apply_dev` varchar(32) NOT NULL DEFAULT '' COMMENT '适用设备类型，如：LC04',
    `file_path` varchar(255) NOT NULL DEFAULT '' COMMENT '压缩包保存路径',
    `decompression_path` varchar(255) NOT NULL DEFAULT '' COMMENT '解压路径',
    `md5` varchar(128) NOT NULL DEFAULT '' COMMENT '压缩包文件MD5值',
    `version` varchar(32) NOT NULL DEFAULT '' COMMENT '主题包版本，如：v1.1.1',
    `min_server_ver` varchar(32) NOT NULL DEFAULT '' COMMENT '主题支持的最小服务器版本，取前两个大版本，如：08.06',
    `remark` varchar(512) NOT NULL DEFAULT '' COMMENT '主题说明、备注',
    `download_progress` tinyint(4) UNSIGNED NOT NULL DEFAULT 0 COMMENT '下载进度，0-100',
    `receiving_end_type` int(11) UNSIGNED NOT NULL DEFAULT 1 COMMENT '接收节点类型，0: 设备 1：空间，2：分组',
    `type` tinyint(4) UNSIGNED NOT NULL DEFAULT 0 COMMENT '主题类型，0 - 设备主题，1 - 扩展应用，其他值无效',
    `modify_by` int(11) UNSIGNED NULL DEFAULT NULL COMMENT '修改人用户ID',
    `modify_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    `create_time` datetime NOT NULL COMMENT '创建/下载时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '主题模板表' ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`InspectionLog`;
CREATE TABLE `nccs`.`InspectionLog` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `space_list` text CHARACTER SET utf8mb4 COLLATE utf8mb4_bin,
  `space_count` int(11) NOT NULL DEFAULT 0,
  `space_success` int(11) NOT NULL DEFAULT 0,
  `space_fault` int(11) NOT NULL DEFAULT 0,
  `space_uncheck` int(11) NOT NULL DEFAULT 0,
  `begin_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '开始时间',
  `dev_count` int(11) NOT NULL DEFAULT 0,
  `dev_success` int(11) NOT NULL DEFAULT 0,
  `dev_fault` int(11) NOT NULL DEFAULT 0,
  `dev_uncheck` int(11) NOT NULL DEFAULT 0,
  `check_count` int(11) NOT NULL DEFAULT 0,
  `uncheck_count` int(11) NOT NULL DEFAULT 0,
  `fault_count` int(11) NOT NULL DEFAULT 0,
  `end_time` timestamp NULL DEFAULT NULL,
  `owner` int(11) NOT NULL DEFAULT 0,
  `owner_name` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin;

-- ----------------------------
-- Table structure for InspectionSpaceRecord
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`InspectionSpaceRecord`;
CREATE TABLE `nccs`.`InspectionSpaceRecord` (
  `id` int NOT NULL AUTO_INCREMENT,
  `task_log_id` int NOT NULL,
  `space_id` int NOT NULL,
  `begin_time` timestamp NULL DEFAULT NULL,
  `fault` smallint NOT NULL DEFAULT '0',
  `check` smallint NOT NULL,
  `uncheck` smallint NOT NULL,
  `end_time` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `uidx_task_log_id_space_id` (`task_log_id`,`space_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin;

-- ----------------------------
-- Table structure for InspectionResult
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`InspectionResult`;
CREATE TABLE `nccs`.`InspectionResult` (
  `id` int NOT NULL AUTO_INCREMENT,
  `task_log_id` int NOT NULL COMMENT '巡检任务记录ID',
  `space_id` int NOT NULL COMMENT '空间ID',
  `begin_time` timestamp NULL DEFAULT NULL,
  `device_type` varchar(16) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL COMMENT '设备分类',
  `device_sn` varchar(64) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL COMMENT '设备序列号',
  `device_ip` varchar(64) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin DEFAULT '' COMMENT '设备IP',
  `check_type` int NOT NULL COMMENT '检查项目',
  `check_code` int NOT NULL COMMENT '检测结果错误码',
  `result` varchar(64) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '检查结果',
  `detail_type` int NOT NULL DEFAULT '0',
  `detail` text CHARACTER SET utf8mb4 COLLATE utf8mb4_bin,
  `end_time` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `uidx_task_log_id_space_id_check_type_device_sn` (`task_log_id`,`space_id`,`check_type`,`device_sn`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin;

-- ----------------------------
-- Table structure for InspectionPlayingTask
-- ----------------------------
DROP TABLE IF EXISTS `InspectionPlayingTask`;
CREATE TABLE `InspectionPlayingTask` (
  `id` int NOT NULL AUTO_INCREMENT,
  `task_log_id` int NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `uidx_task_log_id` (`task_log_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin;



-- ----------------------------
-- Table structure for Msg
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`Msg`;
CREATE TABLE IF NOT EXISTS `nccs`.`Msg`  (
     `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键',
     `title` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT ' 标题',
     `type` tinyint(4) NOT NULL COMMENT '类型 1：设备离线通知、2：设备硬件故障、3：用户上报故障、4、IP呼叫无人接听、5：设备IP冲突、6：云端公告，7：服务器运行告警',
     `source` tinyint(4) NOT NULL COMMENT '来源 1：基础平台，2：设备，3:用户，4：云端',
     `data` text CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL COMMENT '每个消息的具体数据、根据类别不同，结构不同',
     `content` text CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL  COMMENT '内容',
     `occurrence_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) COMMENT '消息的发送时间',
     `push_status` tinyint NOT NULL DEFAULT '0' COMMENT '是否已推送至云端',
     `create_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) COMMENT '创建时间',
     `update_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '修改时间',
     PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_general_ci ROW_FORMAT = Dynamic;


-- ----------------------------
-- Table structure for UserMsg
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`UserMsg`;
CREATE TABLE IF NOT EXISTS`nccs`.`UserMsg`  (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键',
    `user_id` int(11) NOT NULL COMMENT '用户ID',
    `msg_id` int(11) NOT NULL COMMENT '消息ID',
    `is_read` tinyint(1) NOT NULL COMMENT '是否已读 0：未读，1：已读',
    `read_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) COMMENT '读取时间、默认创建时间',
    `processed_status` tinyint(1) NOT NULL COMMENT '0:无需处理，1：待处理，2：已处理',
    `processed_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) COMMENT '处理时间、默认创建时间',
    `create_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) COMMENT '创建时间',
    `update_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '修改时间',
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `user_id`(`user_id`, `msg_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_general_ci ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for LicenseImportRecord
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`LicenseImportRecord`;
CREATE TABLE `nccs`.`LicenseImportRecord`  (
  `type` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL COMMENT '证书类型。0：开发证书 1：试用证书 2：生产证书',
  `uuid` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL COMMENT '学校uuid',
  `school_name` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL COMMENT '学校名称',
  `md5` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '证书zip包的md5值',
  `number` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL COMMENT '证书编号',
  `content` varchar(4096) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '解密后的证书内容',
  `create_date` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL COMMENT '证书生成时间',
  `import_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '证书导入时间',
  `expire_date` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '证书过期时间'
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`Zone`;
CREATE TABLE IF NOT EXISTS `nccs`.`Zone`  (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `name` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT ' 校区名称',
  `create_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) COMMENT '创建时间',
  `update_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '修改时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`ReserveSpaceStatus`;
CREATE TABLE IF NOT EXISTS `nccs`.`ReserveSpaceStatus`  (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键',
    `state` tinyint(4) NOT NULL COMMENT '状态 0：关闭，1：有课，2：开放，3：已预约,4：已锁定（已开始预约）,5: 自习室',
    `space_id` int(11) NOT NULL COMMENT '空间ID',
    `section_id` int(11) NOT NULL COMMENT '节次ID',
    `section_name`  varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin DEFAULT '' COMMENT '节次名称',
    `start` time NOT NULL DEFAULT '00:00:00',
    `end` time NOT NULL DEFAULT '00:00:00',
    `week` int(3) NOT NULL DEFAULT '0' COMMENT '上课周次',
    `week_day` tinyint(4) NOT NULL COMMENT '上课星期',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_general_ci ROW_FORMAT = Dynamic;


DROP TABLE IF EXISTS `nccs`.`Reserve`;
CREATE TABLE IF NOT EXISTS `nccs`.`Reserve`  (
     `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键',
     `space_id` int(11) NOT NULL COMMENT '空间ID',
     `section_ids` varchar(255) NOT NULL DEFAULT '' COMMENT '开始节次ID',
     `week` int(3) NOT NULL DEFAULT '0' COMMENT '上课周次',
     `week_day` tinyint(4) NOT NULL COMMENT '上课星期',
     `apply_user_id` int(11) NOT NULL COMMENT '申请人',
     `is_proxy` tinyint(1) NOT NULL COMMENT '是否代申请 0：申请人既是使用人，1：非使用人（代申请）:',
     `use_name` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '使用人姓名',
     `use_phone` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '使用人电话',
     `use_sn` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '使用人学工号',
     `use_ic` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '使用人IC卡号',
     `purpose` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '用途',
     `state` tinyint(4) NOT NULL COMMENT '状态 0：待审核，1：不通过，2：通过、3：已撤销',
     `qrcode` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '预约反扫二维码',
     `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
     `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
     PRIMARY KEY (`id`)
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`ReserveAudit`;
CREATE TABLE IF NOT EXISTS `nccs`.`ReserveAudit`  (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `reserve_id` int(11) NOT NULL COMMENT '预约ID',
  `name` varchar(255) NOT NULL COMMENT '审核节点名称',
  `user_id` int(11) NOT NULL COMMENT '处理人ID',
  `user_name`varchar(255) NOT NULL COMMENT '处理人',
  `state` tinyint(4) NOT NULL COMMENT '状态 0：已申请，1：未通过，2：已通过、3：已撤销',
  `remark`varchar(255) NOT NULL COMMENT '备注',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`WorkOrder`;
CREATE TABLE `nccs`.`WorkOrder`  (
     `id` int NOT NULL AUTO_INCREMENT,
     `type` tinyint NOT NULL COMMENT ' 0,1 表示设备故障、教室巡检',
     `space_id` int NOT NULL COMMENT '空间ID',
     `asset_id` int NOT NULL COMMENT '资产ID',
     `recipient_user_id` int NOT NULL COMMENT '接单人ID',
     `contacts` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '联系人',
     `deadline` date NULL DEFAULT NULL COMMENT '截至时间',
     `describe` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '描述',
     `priority` int NOT NULL DEFAULT '0' COMMENT '优先级 0,1,2 高中低 ',
     `create_user_id` int NOT NULL COMMENT '创建人',
     `state` tinyint NOT NULL COMMENT '0,1,2 分别表示处理中。已完成、已关闭',
     `fault_start_time` datetime DEFAULT NULL COMMENT '故障时间',
     `end_time` datetime DEFAULT NULL COMMENT '工单结束时间/关闭时间',
     `create_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) COMMENT '创建时间',
     `update_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '修改时间',
     PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`TaskNodeHistory`;
CREATE TABLE `nccs`.`TaskNodeHistory`  (
   `id` int NOT NULL AUTO_INCREMENT,
   `task_node_id` int NOT NULL,
   `task_node_name` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
   `business_id` int NOT NULL COMMENT '业务id',
   `business_type` tinyint NOT NULL COMMENT '0:工单。',
   `audit_user_id` int NOT NULL COMMENT '审核人',
   `audit_time` datetime(0) NOT NULL,
   `audit_param` varchar(1024) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL COMMENT '审核时，传入的参数的map字符串数据',
   `create_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) COMMENT '创建时间',
   `update_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '修改时间',
   PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`TaskNodeRun`;
CREATE TABLE `nccs`.`TaskNodeRun`  (
   `id` int NOT NULL AUTO_INCREMENT,
   `task_node_id` int NOT NULL,
   `task_node_name` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
   `audit_user_id` int NOT NULL,
   `business_id` int NOT NULL COMMENT '业务ID',
   `business_type` tinyint NOT NULL DEFAULT 0 COMMENT '流程类型 0 表示工单',
   `variable_map` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL COMMENT '流程运行时。流程变量',
   `create_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) COMMENT '创建时间',
   `update_time` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '修改时间',
   PRIMARY KEY (`id`) USING BTREE,
   INDEX `business_id`(`business_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin ROW_FORMAT = Dynamic;


-- ----------------------------
-- Table structure for IPCallRecord
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`IPCallRecord`;
CREATE TABLE IF NOT EXISTS `nccs`.`IPCallRecord`  (
    `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `dev_id` varchar(50) NOT NULL DEFAULT '' COMMENT '主叫或被叫设备ID',
    `dev_ip` varchar(50) NOT NULL DEFAULT '' COMMENT '主叫或被叫设备IP',
    `space_id` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '主叫或被叫空间ID',
    `direction` tinyint(1) UNSIGNED NOT NULL COMMENT 'IP对讲方向：1 - 设备主叫，2 - Web 控制台主叫',
    `call_uid` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT 'IP呼叫发起方用户ID，0-无效值',
    `call_time` bigint(20) UNSIGNED NOT NULL DEFAULT 0 COMMENT 'IP呼叫发起时间，秒级时间戳',
    `call_type` varchar(32) NOT NULL COMMENT '呼叫类型：0 - WebRTC 音频，兼容老中控；1 -  WebRTC 音频；2 - WebRTC 视频',
    `pickup_uid` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT 'IP呼叫接听方用户ID，0-无效值',
    `pickup_time` bigint(20) UNSIGNED NOT NULL DEFAULT 0 COMMENT '接听时间，秒级时间戳',
    `end_time` bigint(20) UNSIGNED NOT NULL DEFAULT 0 COMMENT '结束时间(包括挂断、超时等情况)，秒级时间戳',
    `status` tinyint(1) UNSIGNED NOT NULL DEFAULT 0 COMMENT '呼叫状态：0 - 未接听，1 -  已接听，2 - 已回拨',
    `remark` varchar(255) NOT NULL DEFAULT '' COMMENT '备注',
    `modify_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = 'IP对讲记录表' ROW_FORMAT = DYNAMIC;


-- ----------------------------
-- Table structure for IPCallRecordFiles
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`IPCallRecordFiles`;
CREATE TABLE IF NOT EXISTS `nccs`.`IPCallRecordFiles`  (
    `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `record_id` int(11) UNSIGNED NOT NULL COMMENT 'IP呼叫记录ID，IPCallRecord.id',
    `type` tinyint(1) NOT NULL DEFAULT 1 COMMENT '文件类型，1-音频文件，2-视频文件',
    `name` varchar(128) NOT NULL DEFAULT '' COMMENT '最终混合文件名称',
    `from_path` varchar(255) NOT NULL DEFAULT '' COMMENT '设备上行媒体流文件存储路径，/home/upload/ipcall/xxx 格式',
    `to_path` varchar(255) NOT NULL DEFAULT '' COMMENT '下行到设备媒体流文件存储路径，/home/upload/ipcall/xxx 格式',
    `mixed_path` varchar(255) NOT NULL DEFAULT '' COMMENT '混合文件路径，/home/upload/ipcall/xxx 格式',
    `size` bigint(20) UNSIGNED NOT NULL DEFAULT 0 COMMENT '混合文件大小，单位：字节',
    `sample_rate` int(11) UNSIGNED NOT NULL COMMENT '音频采样率，1: 8000; 2: 16000; 3: 22050; 4: 32000; 5: 44100; 6: 48000',
    `create_time` bigint(20) UNSIGNED NOT NULL DEFAULT 0 COMMENT '文件创建时间，秒级时间戳',
    `status` tinyint(1) UNSIGNED NOT NULL DEFAULT 0 COMMENT '文件状态，0 - 无效/转换失败，1 - 写入中，2 - 写入完成',
    `modify_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    `modify_by` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '修改人ID',
    `is_deleted` tinyint(1) UNSIGNED NOT NULL DEFAULT 0 COMMENT '文件是否被删除，0 - 否，1 - 是',
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `record_id_idx`(`record_id`) USING BTREE COMMENT '录音文件ID索引'
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = 'IP对讲文件记录表' ROW_FORMAT = DYNAMIC;

-- ----------------------------
-- Table structure for SpaceAndPC
-- ----------------------------
DROP TABLE IF EXISTS `SpaceAndPC`;
CREATE TABLE `SpaceAndPC`  (
  `pc_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '电脑ID',
  `space_id` int(11) NOT NULL COMMENT '空间ID',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`pc_id`) USING BTREE,
  INDEX `space_id`(`space_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = DYNAMIC;

-- ----------------------------
-- Table structure for ValueAddedInitRecord
-- ----------------------------
DROP TABLE IF EXISTS `ValueAddedInitRecord`;
CREATE TABLE `ValueAddedInitRecord`  (
  `id` int(11) NOT NULL DEFAULT 0 COMMENT '增值服务id',
  `name` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '增值服务名称',
  `code` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '增值服务code',
  `apply_time` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '增值服务创建时间',
  `expire_time` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '增值服务过期时间',
  `is_new` tinyint(1) NOT NULL DEFAULT 1 COMMENT '该增值服务是否是新增',
  PRIMARY KEY (`code`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin ROW_FORMAT = Dynamic;


-- ----------------------------
-- Table structure for ExtAppConfig
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`ExtAppConfig`;
CREATE TABLE `nccs`.`ExtAppConfig`  (
    `dev_id` varchar(50) NOT NULL COMMENT '设备ID',
    `type` tinyint(1) UNSIGNED NOT NULL DEFAULT 1 COMMENT '配置类型，1 - idste，2 - 第三方',
    `theme_ids` text NULL COMMENT '关联的云端主题ID，关联多个时id之间以逗号分隔',
    `config` text NULL COMMENT '信息发布配置，非第三方时，URL 动态解析生成',
    `qrcode_config` text NULL COMMENT '二维码配置',
    `receiving_end_type` int(11) UNSIGNED NOT NULL DEFAULT 1 COMMENT '接收节点类型，0: 设备 1：空间，2：分组',
    `modify_by` int(11) NULL DEFAULT NULL COMMENT '修改人ID',
    `modify_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`dev_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '设备扩展应用配置表' ROW_FORMAT = DYNAMIC;


-- ----------------------------
-- Table structure for ExtAppConfig
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`ExtAppPartitionNode`;
CREATE TABLE `nccs`.`ExtAppPartitionNode`  (
    `dev_id` varchar(50) NOT NULL COMMENT '设备ID',
    `partition_id` int(11) UNSIGNED NOT NULL COMMENT '分区节点ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    UNIQUE INDEX `uidx_devid_nodeid`(`dev_id`, `partition_id`) USING BTREE COMMENT '设备ID和分区节点ID索引'
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '设备扩展应用分区节点绑定表' ROW_FORMAT = DYNAMIC;


DROP TABLE IF EXISTS `nccs`.`Answer`;
CREATE TABLE `nccs`.`Answer`
(
    `id`              int                                                    NOT NULL AUTO_INCREMENT COMMENT '主键',
    `evaluation_id`   int                                                    NOT NULL COMMENT '评论id',
    `question_id`     int                                                    NOT NULL COMMENT '问题ID',
    `title`           varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '问题标题',
    `type`            tinyint                                                NOT NULL DEFAULT '0' COMMENT '0：单项。1：多选，2：简答',
    `order_index`     int                                                    NOT NULL DEFAULT '0' COMMENT '排序号',
    `question_option` varchar(4096) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT 'Json 字符串 数组',
    `answer_option`   varchar(4096) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT 'Json 字符串 数组',
    `create_time`     datetime                                               NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_time`     datetime                                               NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  AUTO_INCREMENT = 1
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_bin COMMENT ='巡课评论 答案表';


DROP TABLE IF EXISTS `nccs`.`Evaluation`;
CREATE TABLE `nccs`.`Evaluation`
(
    `id`                     int                                                    NOT NULL AUTO_INCREMENT COMMENT '主键',
    `title`                  varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '评论标题',
    `evaluation_template_id` int                                                    NOT NULL COMMENT '评论模板ID',
    `create_user_id`         int                                                    NOT NULL DEFAULT '0',
    `create_time`            datetime                                               NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_time`            datetime                                               NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  AUTO_INCREMENT = 1
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_bin COMMENT ='巡课评论表';

DROP TABLE IF EXISTS `nccs`.`EvaluationTemplate`;
CREATE TABLE `nccs`.`EvaluationTemplate`
(
    `id`             int          NOT NULL AUTO_INCREMENT COMMENT '主键',
    `title`          varchar(255) NOT NULL DEFAULT '' COMMENT '评论模板标题',
    `is_deleted`     tinyint      NOT NULL DEFAULT '0' COMMENT '0：未删除。1：已删除',
    `create_user_id` int          NOT NULL DEFAULT '0',
    `create_time`    datetime     NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_time`    datetime     NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  AUTO_INCREMENT = 1
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_bin COMMENT ='巡课模板表';

DROP TABLE IF EXISTS `nccs`.`Question`;
CREATE TABLE `nccs`.`Question`
(
    `id`                     int                                                    NOT NULL AUTO_INCREMENT COMMENT '主键',
    `evaluation_template_id` int                                                    NOT NULL COMMENT '评论模板id',
    `title`                  varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '问题标题',
    `type`                   tinyint                                                NOT NULL DEFAULT '0' COMMENT '0：单项。1：多选，2：简答',
    `order_index`            int                                                    NOT NULL DEFAULT '0' COMMENT '排序号',
    `option`                 varchar(4096) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT 'Json 字符串数组',
    `is_deleted`             tinyint                                                NOT NULL DEFAULT '0' COMMENT '0:未删除。1：已删除',
    `create_user_id`         int                                                    NOT NULL DEFAULT '0',
    `create_time`            datetime                                               NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_time`            datetime                                               NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  AUTO_INCREMENT = 10
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_bin COMMENT ='巡课问题表';


-- ---------------------------------------------
-- Table structure for ExtAppPreviewPartitionNode
-- ---------------------------------------------
DROP TABLE IF EXISTS `nccs`.`ExtAppPreviewPartitionNode`;
CREATE TABLE `nccs`.`ExtAppPreviewPartitionNode`  (
    `theme_id` bigint(20) UNSIGNED NOT NULL COMMENT '主题云端id',
    `partition_id` int(11) UNSIGNED NOT NULL COMMENT '分区节点ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    UNIQUE INDEX `uidx_tid_pid`(`theme_id`, `partition_id`) USING BTREE COMMENT '主题云端ID和分区节点ID索引'
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '扩展应用预览分区节点绑定表' ROW_FORMAT = DYNAMIC;


SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;