#!/bin/bash

# /usr/sbin/logback.sh  /var/log/supervisor/ /var/log/supervisor/backlog/ /var/log/supervisor/temp/

# 日志备份说明：
# 1. 日志备份任务每10分钟执行一次；
# 2. 如果 iDsteXXX 日志(如：iDsteServers-xxx.log.1)写满(当前50MB)则压缩移动到 backlog 目录；
# 3. 对于 supervisor 重启导致的程序不再使用的临时日志文件(如：iDsteServers-xxx.log、mosquitto-xxx.log等)，统一移动到 temp 目录保存，以免日志积累造成查询困难；
# 4. backlog 目录超过 500MB 时，会循环删除最早备份的日志，直至 backlog 目录降至 500MB 以下；
# 5. temp 目录下的日志保留 30 天，超过 30 天的直接删除。

# 日志文件路径
logPath=$1
# 日志文件备份路径
backupPath=$2
# 日志文件临时存储路径，主要用于 supervisor 重启时临时保存日志文件
tempPath=$3

# 查找日志首次和最后打印时间
function findTime(){
    file_name=$1
    file_type=${file_name#*$logPath}
    file_type=${file_type%%-*}
    first_name=$(head -1 $file_name)
    last_name=$(tail -1 $file_name)
    if [[ $file_type == "iDsteAdapter" || $file_type == "iDsteCamera" || $file_type == "iDsteServers" || $file_type == "iDsteShare" || $file_type == "iDsteVlcPlayer" ]]; then
        if [[ ${first_name:0:4} == "time" || ${first_name:0:4} == "cron" ]]; then
            first_name="${first_name:6:10}-${first_name:17:8}"
        else
            # 获取失败时，直接取文件最后修改时间
            first_name=$(date -r $file_name "+%Y-%m-%d-%H-%M-%S")
        fi

        # 最后打印时间
        if [[ ${last_name:0:4} == "time" || ${last_name:0:4} == "cron"  ]]; then
        	last_name="${last_name:6:10}-${last_name:17:8}"
        else
            # 获取失败时，直接取文件最后修改时间
            last_name=$(date -r $file_name "+%Y-%m-%d-%H-%M-%S")
        fi
    elif [[ $file_type == "iDsteProxy" ]]; then
        # 提取日期时间
        time_str=$(echo $first_name | cut -d' ' -f1 | sed -e 's/time="//' -e 's/"//')
        if [[ ${#time_str} -gt 10 ]]; then
            # 2006-01-02T00:00:00+08:00  ISO 8601 格式
            first_name=$(date -d"$time_str" "+%Y-%m-%d-%H-%M-%S")
        else
            # 2006-01-02 00:00:00 格式
            if [[ ${first_name:0:4} == "time" || ${first_name:0:4} == "cron" ]]; then
                first_name="${first_name:6:10}-${first_name:17:8}"
            else
                # 获取失败时，直接取文件最后修改时间
                first_name=$(date -r $file_name "+%Y-%m-%d-%H-%M-%S")
            fi
        fi

        # 提取日期时间
        time_str=$(echo $last_name | cut -d' ' -f1 | sed -e 's/time="//' -e 's/"//')
        if [[ ${#time_str} -gt 10 ]]; then
            # 2006-01-02T00:00:00+08:00  ISO 8601 格式
            last_name=$(date -d"$time_str" "+%Y-%m-%d-%H-%M-%S")
        else
            # 2006-01-02 00:00:00 格式
            if [[ ${last_name:0:4} == "time" || ${last_name:0:4} == "cron" ]]; then
                last_name="${last_name:6:10}-${last_name:17:8}"
            else
                # 获取失败时，直接取文件最后修改时间
                last_name=$(date -r $file_name "+%Y-%m-%d-%H-%M-%S")
            fi
        fi
    else
       # 无效类型，直接取文件最后修改时间
       first_name=$(date -r $file_name "+%Y-%m-%d-%H-%M-%S")
       last_name=$(date -r $file_name "+%Y-%m-%d-%H-%M-%S")
    fi

	name="time:${first_name=}-${last_name}"
	name=${name//\//-}
}

if [[ $# -ne 3 ]] || [[ ! -d $logPath ]];then
	echo "`date +%y%m%d` error using:logback.sh logdir backlogdir templogdir "
	exit 1
fi

if [[ ! -d $backupPath ]]; then
	mkdir $backupPath
fi

if [[ ! -d $tempPath ]]; then
	mkdir $tempPath
fi


logPrefix="iDste"
# 日志写满后格式类似为：xxx.log.1
logSuffix="log."
# 未写满的日志文件格式为：xxx.log
otherLogSuffix=".log"

cd $logPath

# 日志文件备份
for fileName in $logPath*; do
	if [[ -f $fileName ]] && [[ ${fileName#*$logPath} =~ $logPrefix ]] && [[ ${fileName#*$logPath} =~ $logSuffix ]]; then
	    # iDsteCamera (text/plain; charset=us-ascii)、iDsteShare (text/html; charset=us-ascii) 等英文日志较多，file -ib 推测的编码格式并不一定是 UTF8
	    # 非 UTF8 编码格式，日志文件中可能会有乱码，从日志文件中获取时间时可能会失败；
	    # 如果因乱码等原因获取时间失败，则直接使用文件最后修改时间，优先保证日志能够备份成功
		#if [[ $(file -ib $fileName) == "text/plain; charset=utf-8" ]];then
		#	echo "`date +%y%m%d` file check success $fileName"
		#else
		#	echo "`date +%y%m%d` file check error $fileName $(file -ib $fileName)"
		#	continue
		#fi

		findTime $fileName
		tarName="$name-${fileName#*$logPath}.tar.gz"
		tarName=${tarName//:/-}

        # 备份压缩完成后删除原文件
		tar -czf $tarName ${fileName#*$logPath} && mv -f $tarName $backupPath && rm -f $fileName
		if [ $? -eq 0 ];then
		    echo "`date +%y%m%d` tar success $fileName"
		else
		    echo "`date +%y%m%d` tar error $fileName"
		fi

		# 循环删除 /var/log/supervisor/backlog/ 目录下的历史备份文件，直到目录小于 500MB
	    dirSize=$(du -b $backupPath/ | awk '{print int($1/1024/1024)}')
        minSize=500
        while (($dirSize > $minSize)); do
            echo "`date +%y%m%d` >${minSize}M start rm backup log "
            fileOld=$(ls -rt $backupPath/*.gz|head -1) && echo  "rm -f ${fileOld}" && rm -f ${fileOld}
            dirSize=$(du -b $backupPath/ | awk '{print int($1/1024/1024)}')
        done
    elif [[ -f $fileName ]] && [[ ${fileName#*$logPath} =~ $otherLogSuffix ]]; then
        # lsof 命令存在时才进行移动   >/dev/null 2>&1
        if command -v lsof &>/dev/null; then
            # 其余不满足备份条件日志文件直接移动到临时存储路径，只移动没有被进程占用的文件。
            # 移动文件不会导致文件修改时间发生变更
            # 使用 lsof 检查文件是否被占用
            lsof_output=$(lsof $fileName)

            #if [ -z "$lsof_output" ]; then
            #    echo "move log file '$fileName' to temp path '$tempPath'"
            #    mv -f $fileName $tempPath
            #else
            #    echo "log file '$fileName' occupied by process, ignore move"
            #fi

            if [ -z "$lsof_output" ]; then
                mv -f $fileName $tempPath
            fi
        fi
    fi
done

# 临时日志文件处理
for fileName in $tempPath*; do
	if [[ -f $fileName ]] && [[ ${fileName#*$tempPath} =~ $otherLogSuffix ]]; then
        # 处理其余不参与备份的日志文件，以避免 supervisor 多次重启后无关日志文件积累，造成日志查询困难
        # 获取文件的最后修改时间，YYYY-MM-DD 格式
        lastModifyTime=$(stat -c %y $fileName | awk '{print $1}' | cut -d ' ' -f1)
        # 当前时间
        currentTime=$(date +%Y-%m-%d)
         # 30天内有修改的文件不删除
         if [[ $lastModifyTime < $currentTime ]]; then
            daysDiff=$((($(date -d $currentTime +%s) - $(date -d $lastModifyTime +%s)) / 86400 ))
            if [ $daysDiff -ge 30 ]; then
                echo "delete log file '$fileName', due to its last modify time more than 30 days ago."
                rm -f $fileName
            fi
         fi
    fi
done